/************************************************************************
* EPP RTK C++
* Copyright (C) 2001, 2002 The Global Name Registry, Limited 
* 
* This library is free software; you can redistribute it and/or modify it
* under the terms of the GNU Lesser General Public License as published
* by the Free Software Foundation; either version 2.1 of the License, or
* (at your option) any later version.
*
* This library is distributed in the hope that it will be useful, but
* WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
* Lesser General Public License for more details.
*
* You should have received a copy of the GNU Lesser General Public
* License along with this library; if not, write to the Free Software
* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*
* Contact information:  epprtk@gnr.com
*
*                       EPP RTK
*                       The Global Name Registry, Limited
*                       125 High Holborn
*                       London WC1V 6QA
*                       United Kingdom
************************************************************************/

#ifndef __EPP_COMMAND_H
#define __EPP_COMMAND_H

/** @file epp_Command.h
*  @brief Definition of epp_Command and epp_Command_ref
*  @author Asbjorn Steira Mikkelsen
*/


#include "epp_eppdata.h"
#include "../epp_Extension.h"
#include "epp_Credentials.h"

namespace eppobject { namespace epp {
	
	/// Class containing generic elements used in a request to the server
	class epp_Command {
		
public:
		epp_extension_ref_seq_ref m_extentions; /**< Extension elements used for server-defined command extensions */
		epp_Extension_ref m_ext; /**< DEPRECATED Extension element used for server-defined command extensions */
		epp_trid_ref m_client_trid; /**< Client transaction ID element that uniquely identifies the command to the client */
		
		/// Null constructor
		epp_Command() {
			// Create empty extensions
			m_extentions.ref(new epp_extension_ref_seq());			
		};
		
		/// Destructor
		virtual ~epp_Command() {};
		
		/// Constructor, using simple types when it can
		/// @note Cannot set simple types to NULL
		/// @deprecated Credentials are no longer present and extension is an array
		epp_Command(const epp_Credentials_ref & _m_creds,
					const epp_Extension_ref & _m_ext,
					const epp_trid & _m_client_trid)
		{
			m_ext = _m_ext;
			
			m_extentions.ref(new epp_extension_ref_seq());
			
			// Extension provided?
			if (_m_ext != NULL) {
				m_extentions->push_back(_m_ext);
			}
			
			m_client_trid.ref(new epp_trid(_m_client_trid));
		};
		
		/// Constructor, using only references
		/// @deprecated Credentials are no longer present and extension is an array
		epp_Command(const epp_Credentials_ref & _m_creds,
					const epp_Extension_ref & _m_ext,
					const epp_trid_ref & _m_client_trid)
		{
			m_ext = _m_ext;
			
			m_extentions.ref(new epp_extension_ref_seq());
			
			// Extension provided?
			if (_m_ext != NULL) {
				m_extentions->push_back(_m_ext);
			}
			
			m_client_trid = _m_client_trid;
		};
		
        
		/// Constructor, using simple types when it can
		/// @note Cannot set simple types to NULL
		epp_Command(const epp_extension_ref_seq_ref & _m_extentions,
					const epp_trid & _m_client_trid)
		{
			m_extentions = _m_extentions;
			m_client_trid.ref(new epp_trid(_m_client_trid));
		};
		
		/// Constructor, using only references
		epp_Command(const epp_extension_ref_seq_ref & _m_extentions,
					const epp_trid_ref & _m_client_trid)
		{
			m_extentions = _m_extentions;
			m_client_trid = _m_client_trid;
		};
	};
	
	/// Typedef for the ref to the epp_Command class
	typedef refcnt_ptr<epp_Command> epp_Command_ref;
	
}}

#endif
