/************************************************************************
 * EPP RTK C++
 * Copyright (C) 2001, 2002 The Global Name Registry, Limited 
 * 
 * This library is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published
 * by the Free Software Foundation; either version 2.1 of the License, or
 * (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact information:  epprtk@gnr.com
 *
 *                       EPP RTK
 *                       The Global Name Registry, Limited
 *                       125 High Holborn
 *                       London WC1V 6QA
 *                       United Kingdom
 ************************************************************************/

#ifndef __EPP_CONTACTINFOREQ_H
#define __EPP_CONTACTINFOREQ_H

/** @file epp_ContactInfoReq.h
 *  @brief Definition of epp_ContactInfoReq and epp_ContactInfoReq_ref
 *  @author Asbjorn Steira Mikkelsen
 */

#include "epp_contactdata.h"
#include "epp_GenericReq.h"
#include "epp_AuthInfo.h"

namespace eppobject { namespace contact {

   /// Class containing elements used in contact info requests
   /// @see epp_GenericReq for additional information
   class epp_ContactInfoReq : public epp::epp_GenericReq {
      
    public:
      eppobject::epp::epp_string_ref m_id; /**< Server-unique ID of the contact object to be queried */
      eppobject::epp::epp_AuthInfo_ref m_auth_info; /**< Optional auto info to test the value at the server */
      
      /// Null constructor
      epp_ContactInfoReq() {};
      
      /// Destructor
      virtual ~epp_ContactInfoReq() {}

      /// Constructor, using simple types when it can
      /// @note Cannot set simple types to NULL
      epp_ContactInfoReq(const eppobject::epp::epp_Command_ref & _m_cmd,
			 const eppobject::epp::epp_string & _m_id,
			 const eppobject::epp::epp_AuthInfo_ref & _m_auth_info = NULL)
	: epp::epp_GenericReq(_m_cmd)
	{
	   m_id.ref(new eppobject::epp::epp_string(_m_id));
	   m_auth_info = _m_auth_info;	   
	};
      
      /// Constructor, using only references
      epp_ContactInfoReq(const eppobject::epp::epp_Command_ref & _m_cmd,
			 const eppobject::epp::epp_string_ref & _m_id,
			 const eppobject::epp::epp_AuthInfo_ref & _m_auth_info = NULL)
	: epp::epp_GenericReq(_m_cmd)
	{
	   m_id = _m_id;
	   m_auth_info = _m_auth_info;
	};
   };

   /// Typedef for the ref to the epp_ContactInfoReq class
   typedef refcnt_ptr<epp_ContactInfoReq> epp_ContactInfoReq_ref;
   
}}

#endif
