/************************************************************************
 * EPP RTK C++
 * Copyright (C) 2001, 2002 The Global Name Registry, Limited 
 * 
 * This library is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published
 * by the Free Software Foundation; either version 2.1 of the License, or
 * (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact information:  epprtk@gnr.com
 *
 *                       EPP RTK
 *                       The Global Name Registry, Limited
 *                       125 High Holborn
 *                       London WC1V 6QA
 *                       United Kingdom
 ************************************************************************/

#ifndef __EPP_CONTACTINFORSP_H
#define __EPP_CONTACTINFORSP_H

/* $Header: /cvsroot/epp-rtk/epp-rtk/c++/src/data/epp_ContactInfoRsp.h,v 1.15 2003/07/18 20:21:19 tubadanm Exp $ */

/** @file epp_ContactInfoRsp.h
 *  @brief Definition of epp_ContactInfoRsp and epp_ContactInfoRsp_ref
 *  @author Asbjorn Steira Mikkelsen
 */

#include "epp_contactdata.h"
#include "epp_GenericRsp.h"
#include "epp_ContactNameAddress.h"
#include "epp_ContactPhone.h"
#include "epp_AuthInfo.h"
#include "epp_ContactStatus.h"

namespace eppobject { namespace contact {
   
   /// Class containing elements used in contact info responses
   /// @see epp_GenericRsp for additional information
   class epp_ContactInfoRsp : public epp::epp_GenericRsp {
      
    public:
      eppobject::epp::epp_string_ref m_id; /**< Server-unique identifier for the created contact */
      eppobject::epp::epp_roid_ref m_roid; /**< Repository Object IDentifier assigned to the contact */
      epp_ContactNameAddress_seq_ref m_addresses; /**< Address elements, using either UTF8 or 7-bit US-ASCII character sets */
      epp_ContactNameAddress_ref m_ascii_address; /**< DEPRECATED Address element, using the 7-bit US-ASCII character set */
      epp_ContactNameAddress_ref m_i15d_address; /**< DEPRECATED Internationalized address element, using unrestricted UTF-8 */
      epp_ContactPhone_ref m_voice; /**< Voice telephone number of contact */
      epp_ContactPhone_ref m_fax; /**< Facsimile telephone number of contact */
      eppobject::epp::epp_string_ref m_email; /**< E-mail address of contact */
      epp_contact_status_seq_ref m_status; /**< Status of the contact object */
      eppobject::epp::epp_string_ref m_client_id; /**< Identifier of the sponsoring client */
      eppobject::epp::epp_string_ref m_created_by; /**< Identifier of the client that created the contact */
      eppobject::epp::epp_datetime_ref m_created_date; /**< Date and time of contact object creation */
      eppobject::epp::epp_string_ref m_updated_by; /**< Identifier of the client that last updated the contact */
      eppobject::epp::epp_datetime_ref m_updated_date; /**< Date and time of the most recent object modification */
      eppobject::epp::epp_datetime_ref m_transfer_date; /**< Date and time of the most recent successful object transfer */
      eppobject::epp::epp_AuthInfo_ref m_auth_info; /**< Authorization information associated with contact */
      
      /// Null constructor
      epp_ContactInfoRsp() {};
      
      /// Destructor
      virtual ~epp_ContactInfoRsp() {}
      
      /// Constructor, using simple types when it can
      /// @note Cannot set simple types to NULL
      /// @deprecated
      epp_ContactInfoRsp(const eppobject::epp::epp_Response_ref & _m_rsp,
			 const eppobject::epp::epp_string & _m_id,
			 const eppobject::epp::epp_roid & _m_roid,
			 const epp_ContactNameAddress_ref & _m_ascii_address,
			 const epp_ContactNameAddress_ref & _m_i15d_address,
			 const epp_ContactPhone_ref & _m_voice,
			 const epp_ContactPhone_ref & _m_fax,
			 const eppobject::epp::epp_string & _m_email,
			 const epp_contact_status_seq_ref & _m_status,
			 const eppobject::epp::epp_string & _m_client_id,
			 const eppobject::epp::epp_string & _m_created_by,
			 const eppobject::epp::epp_datetime & _m_created_date,
			 const eppobject::epp::epp_string & _m_updated_by,
			 const eppobject::epp::epp_datetime & _m_updated_date,
			 const eppobject::epp::epp_datetime & _m_transfer_date,
			 const eppobject::epp::epp_AuthInfo_ref & _m_auth_info)
	: epp::epp_GenericRsp(_m_rsp)
	{
	   m_id.ref(new eppobject::epp::epp_string(_m_id));
	   m_roid.ref(new eppobject::epp::epp_roid(_m_roid));
           m_addresses.ref(new epp_ContactNameAddress_seq());
	   m_ascii_address = _m_ascii_address;
           if ( _m_ascii_address != NULL ) {
              epp_ContactNameAddress i(*_m_ascii_address);
              i.m_type.ref(new epp_ContactPostalInfoType(INT));
              m_addresses->push_back(i);
           }
	   m_i15d_address = _m_i15d_address;
           if ( _m_i15d_address != NULL ) {
              epp_ContactNameAddress i(*_m_i15d_address);
              i.m_type.ref(new epp_ContactPostalInfoType(INT));
              m_addresses->push_back(i);
           }
	   m_voice = _m_voice;
	   m_fax = _m_fax;
	   m_email.ref(new eppobject::epp::epp_string(_m_email));
	   m_status = _m_status;
	   m_client_id.ref(new eppobject::epp::epp_string(_m_client_id));
	   m_created_by.ref(new eppobject::epp::epp_string(_m_created_by));
	   m_created_date.ref(new eppobject::epp::epp_datetime(_m_created_date));
	   m_updated_by.ref(new eppobject::epp::epp_string(_m_updated_by));
	   m_updated_date.ref(new eppobject::epp::epp_datetime(_m_updated_date));
	   m_transfer_date.ref(new eppobject::epp::epp_datetime(_m_transfer_date));
	   m_auth_info = _m_auth_info;
	};
      
      /// Constructor, using only references
      /// @deprecated
      epp_ContactInfoRsp(const eppobject::epp::epp_Response_ref & _m_rsp,
			 const eppobject::epp::epp_string_ref & _m_id,
			 const eppobject::epp::epp_roid_ref & _m_roid,
			 const epp_ContactNameAddress_ref & _m_ascii_address,
			 const epp_ContactNameAddress_ref & _m_i15d_address,
			 const epp_ContactPhone_ref & _m_voice,
		         const epp_ContactPhone_ref & _m_fax,
			 const eppobject::epp::epp_string_ref & _m_email,
			 const epp_contact_status_seq_ref & _m_status,
			 const eppobject::epp::epp_string_ref & _m_client_id,
			 const eppobject::epp::epp_string_ref & _m_created_by,
			 const eppobject::epp::epp_datetime_ref & _m_created_date,
			 const eppobject::epp::epp_string_ref & _m_updated_by,
			 const eppobject::epp::epp_datetime_ref & _m_updated_date,
			 const eppobject::epp::epp_datetime_ref & _m_transfer_date,
			 const eppobject::epp::epp_AuthInfo_ref & _m_auth_info)
	: epp::epp_GenericRsp(_m_rsp)
	{
	   m_id = _m_id;
	   m_roid = _m_roid;
           m_addresses.ref(new epp_ContactNameAddress_seq());
	   m_ascii_address = _m_ascii_address;
           if ( _m_ascii_address != NULL ) {
              epp_ContactNameAddress i(*_m_ascii_address);
              i.m_type.ref(new epp_ContactPostalInfoType(INT));
              m_addresses->push_back(i);
           }
	   m_i15d_address = _m_i15d_address;
           if ( _m_i15d_address != NULL ) {
              epp_ContactNameAddress i(*_m_i15d_address);
              i.m_type.ref(new epp_ContactPostalInfoType(INT));
              m_addresses->push_back(i);
           }
	   m_voice = _m_voice;
	   m_fax = _m_fax;
	   m_email = _m_email;
	   m_status = _m_status;
	   m_client_id = _m_client_id;
	   m_created_by = _m_created_by;
	   m_created_date = _m_created_date;
	   m_updated_by = _m_updated_by;
	   m_updated_date = _m_updated_date;
	   m_transfer_date = _m_transfer_date;
	   m_auth_info = _m_auth_info;
	};

      /// Constructor, using simple types when it can
      /// @note Cannot set simple types to NULL
      epp_ContactInfoRsp(const eppobject::epp::epp_Response_ref & _m_rsp,
			 const eppobject::epp::epp_string & _m_id,
			 const eppobject::epp::epp_roid & _m_roid,
			 const epp_ContactNameAddress_seq_ref & _m_addresses,
			 const epp_ContactPhone_ref & _m_voice,
			 const epp_ContactPhone_ref & _m_fax,
			 const eppobject::epp::epp_string & _m_email,
			 const epp_contact_status_seq_ref & _m_status,
			 const eppobject::epp::epp_string & _m_client_id,
			 const eppobject::epp::epp_string & _m_created_by,
			 const eppobject::epp::epp_datetime & _m_created_date,
			 const eppobject::epp::epp_string & _m_updated_by,
			 const eppobject::epp::epp_datetime & _m_updated_date,
			 const eppobject::epp::epp_datetime & _m_transfer_date,
			 const eppobject::epp::epp_AuthInfo_ref & _m_auth_info)
	: epp::epp_GenericRsp(_m_rsp)
	{
	   m_id.ref(new eppobject::epp::epp_string(_m_id));
	   m_roid.ref(new eppobject::epp::epp_roid(_m_roid));
	   m_addresses = _m_addresses;
           if ( m_addresses != NULL ) {
              for ( epp_ContactNameAddress_seq::iterator i = m_addresses->begin();
                    i != m_addresses->end();
                    i++ ) {
                 if ( *i->m_type == LOC ) {
                    m_i15d_address.ref(new epp_ContactNameAddress(*i));
                 } else {
                    m_ascii_address.ref(new epp_ContactNameAddress(*i));
                 }
              }
           }
	   m_voice = _m_voice;
	   m_fax = _m_fax;
	   m_email.ref(new eppobject::epp::epp_string(_m_email));
	   m_status = _m_status;
	   m_client_id.ref(new eppobject::epp::epp_string(_m_client_id));
	   m_created_by.ref(new eppobject::epp::epp_string(_m_created_by));
	   m_created_date.ref(new eppobject::epp::epp_datetime(_m_created_date));
	   m_updated_by.ref(new eppobject::epp::epp_string(_m_updated_by));
	   m_updated_date.ref(new eppobject::epp::epp_datetime(_m_updated_date));
	   m_transfer_date.ref(new eppobject::epp::epp_datetime(_m_transfer_date));
	   m_auth_info = _m_auth_info;
	};
      
      /// Constructor, using only references
      epp_ContactInfoRsp(const eppobject::epp::epp_Response_ref & _m_rsp,
			 const eppobject::epp::epp_string_ref & _m_id,
			 const eppobject::epp::epp_roid_ref & _m_roid,
			 const epp_ContactNameAddress_seq_ref & _m_addresses,
			 const epp_ContactPhone_ref & _m_voice,
		         const epp_ContactPhone_ref & _m_fax,
			 const eppobject::epp::epp_string_ref & _m_email,
			 const epp_contact_status_seq_ref & _m_status,
			 const eppobject::epp::epp_string_ref & _m_client_id,
			 const eppobject::epp::epp_string_ref & _m_created_by,
			 const eppobject::epp::epp_datetime_ref & _m_created_date,
			 const eppobject::epp::epp_string_ref & _m_updated_by,
			 const eppobject::epp::epp_datetime_ref & _m_updated_date,
			 const eppobject::epp::epp_datetime_ref & _m_transfer_date,
			 const eppobject::epp::epp_AuthInfo_ref & _m_auth_info)
	: epp::epp_GenericRsp(_m_rsp)
	{
	   m_id = _m_id;
	   m_roid = _m_roid;
	   m_addresses = _m_addresses;
           if ( m_addresses != NULL ) {
              for ( epp_ContactNameAddress_seq::iterator i = m_addresses->begin();
                    i != m_addresses->end();
                    i++ ) {
                 if ( *i->m_type == LOC ) {
                    m_i15d_address.ref(new epp_ContactNameAddress(*i));
                 } else {
                    m_ascii_address.ref(new epp_ContactNameAddress(*i));
                 }
              }
           }
	   m_voice = _m_voice;
	   m_fax = _m_fax;
	   m_email = _m_email;
	   m_status = _m_status;
	   m_client_id = _m_client_id;
	   m_created_by = _m_created_by;
	   m_created_date = _m_created_date;
	   m_updated_by = _m_updated_by;
	   m_updated_date = _m_updated_date;
	   m_transfer_date = _m_transfer_date;
	   m_auth_info = _m_auth_info;
	};
   };
   
   /// Typedef for the ref to the epp_ContactInfoRsp class
   typedef refcnt_ptr<epp_ContactInfoRsp> epp_ContactInfoRsp_ref;
   
}}

#endif
