/************************************************************************
 * EPP RTK C++
 * Copyright (C) 2001, 2002 The Global Name Registry, Limited 
 * 
 * This library is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published
 * by the Free Software Foundation; either version 2.1 of the License, or
 * (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact information:  epprtk@gnr.com
 *
 *                       EPP RTK
 *                       The Global Name Registry, Limited
 *                       125 High Holborn
 *                       London WC1V 6QA
 *                       United Kingdom
 ************************************************************************/

#ifndef __EPP_CONTACTSTATUS_H
#define __EPP_CONTACTSTATUS_H

/** @file epp_ContactStatus.h
 *  @brief Definition of epp_ContactStatus and epp_ContactStatus_ref
 *  @author Asbjorn Steira Mikkelsen
 */

#include "epp_contactdata.h"

namespace eppobject { namespace contact {
   
   /// Class containing elements to describe a status of a contact
   class epp_ContactStatus {
      
    public:
      epp_ContactStatusType_ref m_type; /**< Type of contact status */
      eppobject::epp::epp_string_ref m_lang; /**< Language of the human-readable describing text (iso639) */
      eppobject::epp::epp_string_ref m_value; /**< Human-readable text describing the rationale for the applied status */
      
      /// Null constructor
      epp_ContactStatus() {};
      
      /// Destructor
      virtual ~epp_ContactStatus() {};
      
      /// Constructor, using simple types when it can
      /// @note Cannot set simple types to NULL
      epp_ContactStatus(const epp_ContactStatusType & _m_type,
			const eppobject::epp::epp_string & _m_lang,
			const eppobject::epp::epp_string & _m_value)
	{
	   m_type.ref(new epp_ContactStatusType(_m_type));
	   m_lang.ref(new eppobject::epp::epp_string(_m_lang));
	   m_value.ref(new eppobject::epp::epp_string(_m_value));
	};
      
      /// Constructor, using only references
      epp_ContactStatus(const epp_ContactStatusType_ref & _m_type,
			const eppobject::epp::epp_string_ref & _m_lang,
			const eppobject::epp::epp_string_ref & _m_value)
	{
	   m_type = _m_type;
	   m_lang = _m_lang;
	   m_value = _m_value;
	};
   };

   /// Typedef for the ref to the epp_ContactStatus class
   typedef refcnt_ptr<epp_ContactStatus> epp_ContactStatus_ref;
   
}}

#endif
