/************************************************************************
 * EPP RTK C++
 * Copyright (C) 2001, 2002 The Global Name Registry, Limited 
 * 
 * This library is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published
 * by the Free Software Foundation; either version 2.1 of the License, or
 * (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact information:  epprtk@gnr.com
 *
 *                       EPP RTK
 *                       The Global Name Registry, Limited
 *                       125 High Holborn
 *                       London WC1V 6QA
 *                       United Kingdom
 ************************************************************************/

#ifndef __EPP_CREDENTIALS_H
#define __EPP_CREDENTIALS_H

/** @file epp_Credentials.h
 *  @brief Definition of epp_Credentials and epp_Credentials_ref
 *  @author Asbjorn Steira Mikkelsen
 */

#include "epp_eppdata.h"
#include "epp_Options.h"

namespace eppobject { namespace epp {
   
   ///Class containing client identity credentials that provides client identity information
   class epp_Credentials {
      
    public:
      epp_string_ref m_client_id; /**< Client identifier assigned to the client by the server */
      epp_string_ref m_password; /**< Client plain text password */
      epp_string_ref m_new_password; /**< New client plain text password */
      epp_Options_ref m_options; /**< Client options for the command/session */
      
      /// Null constructor
      epp_Credentials() {};
      
      /// Destructor
      virtual ~epp_Credentials() {}
      
      /// Constructor, using simple types when it can
      /// @note Cannot set simple types to NULL
      epp_Credentials(const epp_string & _m_client_id,
		      const epp_string & _m_password,
		      const epp_string & _m_new_password,
		      const epp_Options_ref & _m_options)
	{
	   m_client_id.ref(new epp_string(_m_client_id));
	   m_password.ref(new epp_string(_m_password));
	   m_new_password.ref(new epp_string(_m_new_password));
	   m_options = _m_options;
	};
      
      /// Constructor, using only references
      epp_Credentials(const epp_string_ref & _m_client_id,
		      const epp_string_ref & _m_password,
		      const epp_string_ref & _m_new_password,
		      const epp_Options_ref & _m_options)
	{
	   m_client_id = _m_client_id;
	   m_password = _m_password;
	   m_new_password = _m_new_password;
	   m_options = _m_options;
	};
   };
   
   /// Typedef for the ref to the epp_Credentials class
   typedef refcnt_ptr<epp_Credentials> epp_Credentials_ref;
   
}}

#endif
