/************************************************************************
 * EPP RTK C++
 * Copyright (C) 2001, 2002 The Global Name Registry, Limited 
 * 
 * This library is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published
 * by the Free Software Foundation; either version 2.1 of the License, or
 * (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact information:  epprtk@gnr.com
 *
 *                       EPP RTK
 *                       The Global Name Registry, Limited
 *                       125 High Holborn
 *                       London WC1V 6QA
 *                       United Kingdom
 ************************************************************************/

#ifndef __EPP_DOMAINCREATEREQ_H
#define __EPP_DOMAINCREATEREQ_H

/** @file epp_DomainCreateReq.h
 *  @brief Definition of epp_DomainCreateReq and epp_DomainCreateReq_ref
 *  @author Asbjorn Steira Mikkelsen
 */

#include "epp_domaindata.h"
#include "epp_GenericReq.h"
#include "epp_DomainPeriod.h"
#include "epp_DomainContact.h"
#include "epp_AuthInfo.h"

namespace eppobject { namespace domain {
   
   /// Class containing elements used in domain create requests
   /// @see epp_GenericReq for additional information
   class epp_DomainCreateReq : public epp::epp_GenericReq {

    public:
      eppobject::epp::epp_string_ref m_name; /**< Fully qualified name of the domain object to be created */
      epp_DomainPeriod_ref m_period; /**< Initial registration period of the domain object */
      eppobject::epp::epp_string_seq_ref m_name_servers; /**< Fully qualified names of known host objects to
							   * provide resolution services for the domain */
      eppobject::epp::epp_string_ref m_registrant; /**< ID for the contact object to be associated with the
						     * domain object as the object registrant */
      epp_domain_contact_seq_ref m_contacts; /**< IDs for other contact objects to be associated with the
					       * domain object */
      eppobject::epp::epp_AuthInfo_ref m_auth_info; /**< Authorization information to be associated with domain */
      
      /// Null constructor
      epp_DomainCreateReq() {};

      /// Destructor
      virtual ~epp_DomainCreateReq() {}
      
      /// Constructor, using simple types when it can
      /// @note Cannot set simple types to NULL
      epp_DomainCreateReq(const eppobject::epp::epp_Command_ref & _m_cmd,
			  const eppobject::epp::epp_string & _m_name,
			  const epp_DomainPeriod_ref & _m_period,
			  const eppobject::epp::epp_string_seq_ref & _m_name_servers,
			  const eppobject::epp::epp_string & _m_registrant,
			  const epp_domain_contact_seq_ref & _m_contacts,
			  const eppobject::epp::epp_AuthInfo_ref & _m_auth_info)
	: epp::epp_GenericReq(_m_cmd)
	{
	   m_name.ref(new eppobject::epp::epp_string(_m_name));
	   m_period = _m_period;
	   m_name_servers = _m_name_servers;
	   m_registrant.ref(new eppobject::epp::epp_string(_m_registrant));
	   m_contacts = _m_contacts;
	   m_auth_info = _m_auth_info;
	};
      
      /// Constructor, using only references
      epp_DomainCreateReq(const eppobject::epp::epp_Command_ref & _m_cmd,
			  const eppobject::epp::epp_string_ref & _m_name,
			  const epp_DomainPeriod_ref & _m_period,
			  const eppobject::epp::epp_string_seq_ref & _m_name_servers,
			  const eppobject::epp::epp_string_ref & _m_registrant,
			  const epp_domain_contact_seq_ref & _m_contacts,
			  const eppobject::epp::epp_AuthInfo_ref & _m_auth_info)
	: epp::epp_GenericReq(_m_cmd)
	{
	   m_name = _m_name;
	   m_period = _m_period;
	   m_name_servers = _m_name_servers;
	   m_registrant = _m_registrant;
	   m_contacts = _m_contacts;
	   m_auth_info = _m_auth_info;
	};
   };
   
   /// Typedef for the ref to the epp_DomainCreateReq class
   typedef refcnt_ptr<epp_DomainCreateReq> epp_DomainCreateReq_ref;
   
}}

#endif
