/************************************************************************
 * EPP RTK C++
 * Copyright (C) 2001, 2002 The Global Name Registry, Limited 
 * 
 * This library is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published
 * by the Free Software Foundation; either version 2.1 of the License, or
 * (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact information:  epprtk@gnr.com
 *
 *                       EPP RTK
 *                       The Global Name Registry, Limited
 *                       125 High Holborn
 *                       London WC1V 6QA
 *                       United Kingdom
 ************************************************************************/

#ifndef __EPP_DOMAININFOREQ_H
#define __EPP_DOMAININFOREQ_H

/** @file epp_DomainInfoReq.h
 *  @brief Definition of epp_DomainInfoReq and epp_DomainInfoReq_ref
 *  @author Asbjorn Steira Mikkelsen
 */

#include "epp_domaindata.h"
#include "epp_GenericReq.h"
#include "epp_AuthInfo.h"

namespace eppobject { namespace domain {
   
   /// Class containing elements used in domain info requests
   /// @see epp_GenericReq for additional information
   class epp_DomainInfoReq : public epp::epp_GenericReq {

    public:
      eppobject::epp::epp_string_ref m_name; /**< Fully qualified name of the domain object to be queried */
      epp_DomainHostsType_ref m_hosts_type; /**< Used to control return of information describing hosts related to the domain object */
      eppobject::epp::epp_AuthInfo_ref m_auth_info; /**< Optional auto info to test the value at the server */
      
      /// Null constructor
      epp_DomainInfoReq() {};
      
      /// Destructor
      virtual ~epp_DomainInfoReq() {}
      
      /// Constructor, using simple types when it can
      /// @note Cannot set simple types to NULL
      epp_DomainInfoReq(const eppobject::epp::epp_Command_ref & _m_cmd,
			const eppobject::epp::epp_string & _m_name,
			const epp_DomainHostsType_ref & _m_hosts_type,
                        const eppobject::epp::epp_AuthInfo_ref & _m_auth_info = NULL)
	: epp::epp_GenericReq(_m_cmd)
	{
	   m_name.ref(new eppobject::epp::epp_string(_m_name));
	   m_hosts_type = _m_hosts_type;
           m_auth_info = _m_auth_info;
	};
      
      /// Constructor, using only references
      epp_DomainInfoReq(const eppobject::epp::epp_Command_ref & _m_cmd,
			const eppobject::epp::epp_string_ref & _m_name,
			const epp_DomainHostsType_ref & _m_hosts_type,
                        const eppobject::epp::epp_AuthInfo_ref & _m_auth_info = NULL)
	: epp::epp_GenericReq(_m_cmd)
	{
	   m_name = _m_name;
	   m_hosts_type = _m_hosts_type;
           m_auth_info = _m_auth_info;
	};
   };

   /// Typedef for the ref to the epp_DomainInfoReq class
   typedef refcnt_ptr<epp_DomainInfoReq> epp_DomainInfoReq_ref;
   
}}

#endif
