/************************************************************************
 * EPP RTK C++
 * Copyright (C) 2001, 2002 The Global Name Registry, Limited 
 * 
 * This library is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published
 * by the Free Software Foundation; either version 2.1 of the License, or
 * (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact information:  epprtk@gnr.com
 *
 *                       EPP RTK
 *                       The Global Name Registry, Limited
 *                       125 High Holborn
 *                       London WC1V 6QA
 *                       United Kingdom
 ************************************************************************/

#ifndef __EPP_DOMAINRENEWREQ_H
#define __EPP_DOMAINRENEWREQ_H

/** @file epp_DomainRenewReq.h
 *  @brief Definition of epp_DomainRenewReq and epp_DomainRenewReq_ref
 *  @author Asbjorn Steira Mikkelsen
 */

#include "epp_domaindata.h"
#include "epp_GenericReq.h"
#include "epp_DomainPeriod.h"

namespace eppobject { namespace domain {
   
   /// Class containing elements used in domain renew requests
   /// @see epp_GenericReq for additional information
   class epp_DomainRenewReq : public epp::epp_GenericReq {
      
    public:
      eppobject::epp::epp_string_ref m_name; /**< Fully qualified name of the domain object to be renewed */
      eppobject::epp::epp_date_ref m_current_expiration_date; /**< Date on which the current validity period ends */
      epp_DomainPeriod_ref m_period; /**< Number of units to be added to the registration period of the domain */
      
      /// Null constructor
      epp_DomainRenewReq() {};
      
      /// Destructor
      virtual ~epp_DomainRenewReq() {}
      
      /// Constructor, using simple types when it can
      /// @note Cannot set simple types to NULL
      epp_DomainRenewReq(const eppobject::epp::epp_Command_ref & _m_cmd,
			 const eppobject::epp::epp_string & _m_name,
			 const eppobject::epp::epp_date & _m_current_expiration_date,
			 const epp_DomainPeriod_ref & _m_period)
	: epp::epp_GenericReq(_m_cmd)
	{
	   m_name.ref(new eppobject::epp::epp_string(_m_name));
	   m_current_expiration_date.ref(new eppobject::epp::epp_date(_m_current_expiration_date));
	   m_period = _m_period;
	};
      
      /// Constructor, using only references
      epp_DomainRenewReq(const eppobject::epp::epp_Command_ref & _m_cmd,
			 const eppobject::epp::epp_string_ref & _m_name,
			 const eppobject::epp::epp_date_ref & _m_current_expiration_date,
			 const epp_DomainPeriod_ref & _m_period)
	: epp::epp_GenericReq(_m_cmd)
	{
	   m_name = _m_name;
	   m_current_expiration_date = _m_current_expiration_date;
	   m_period = _m_period;
	};
   };
   
   /// Typedef for the ref to the epp_DomainRenewReq class
   typedef refcnt_ptr<epp_DomainRenewReq> epp_DomainRenewReq_ref;
   
}}

#endif
