/************************************************************************
 * EPP RTK C++
 * Copyright (C) 2001, 2002 The Global Name Registry, Limited 
 * 
 * This library is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published
 * by the Free Software Foundation; either version 2.1 of the License, or
 * (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact information:  epprtk@gnr.com
 *
 *                       EPP RTK
 *                       The Global Name Registry, Limited
 *                       125 High Holborn
 *                       London WC1V 6QA
 *                       United Kingdom
 ************************************************************************/


/** @file epp_DomainTrnData.cc
 *  @brief Additional definitions for epp_DomainTrnData
 *  @author Asbjorn Steira Mikkelsen
 *  @see epp_DomainTrnData.h
 */

#include <domtools/dom_wrapper.h>
#include "epp_DomainTrnData.h"
#include "epp_domainXMLbase.h"

using namespace std;
using namespace eppobject::domain;
using namespace eppobject::epp;
using namespace domtools;

eppobject::epp::epp_PollResData_ref epp_DomainTrnData::createPollResData(const domtools::dom_ptr & trnNode)
{
   epp_DomainTrnData_ref domt(new epp_DomainTrnData());
   
   if(!trnNode->isNull()) {
      dom_ptr DTChildNode = dom_ptr(trnNode->getFirstChildElement());
      
      string elemPrefix = trnNode->getPrefix();
      
      while(!DTChildNode->isNull()) {
	 string nodeName = DTChildNode->getNodeName();
	 
	 if(nodeName == string(elemPrefix + ":name")) {
	    domt->m_name.ref(new epp_string(DTChildNode->getNodeData()));
//	    cout << "name: " << *domt->m_name << endl;
	 } // if "name"
	 
	 else if(nodeName == string(elemPrefix + ":trStatus")) {
	    string trStatus = DTChildNode->getNodeData();
	    domt->m_transfer_status.ref(new epp_TransferStatusType(returnTransferStatusType(trStatus)));
//	    cout << "trStatus: " << trStatus << endl;
	 } // if "trStatus"
	 
	 else if(nodeName == string(elemPrefix + ":reID")) {
	    domt->m_request_client_id.ref(new epp_string(DTChildNode->getNodeData()));
//	    cout << "reID: " << *domt->m_request_client_id << endl;
	 } // if "reID"
	 
	 else if(nodeName == string(elemPrefix + ":reDate")) {
	    domt->m_request_date.ref(new epp_string(DTChildNode->getNodeData()));
//	    cout << "reDate: " << *domt->m_request_date << endl;
	 } // if "reDate"
	 
	 else if(nodeName == string(elemPrefix + ":acID")) {
	    domt->m_action_client_id.ref(new epp_string(DTChildNode->getNodeData()));
//	    cout << "acID: " << *domt->m_action_client_id << endl;        
	 } // if "acID"
	 
	 else if(nodeName == string(elemPrefix + ":acDate")) {
	    domt->m_action_date.ref(new epp_string(DTChildNode->getNodeData()));
//	    cout << "acDate: " << *domt->m_action_date << endl;
	 } // if "acDate"
	 
	 else if(nodeName == string(elemPrefix + ":exDate")) {
	    domt->m_expiration_date.ref(new epp_datetime(DTChildNode->getNodeData()));
//	    cout << "exDate: " << *domt->m_expiration_date << endl;
	 } // if "exDate"
	 
	 DTChildNode = dom_ptr(DTChildNode->getNextSiblingElement());
      } // while "DTChildNode"
      
   } // if "trnNode"
   
   return domt;
   
} // createPollResData
