/************************************************************************
 * EPP RTK C++
 * Copyright (C) 2001, 2002 The Global Name Registry, Limited 
 * 
 * This library is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published
 * by the Free Software Foundation; either version 2.1 of the License, or
 * (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact information:  epprtk@gnr.com
 *
 *                       EPP RTK
 *                       The Global Name Registry, Limited
 *                       125 High Holborn
 *                       London WC1V 6QA
 *                       United Kingdom
 ************************************************************************/

#ifndef __EPP_DOMAINTRNDATA_H
#define __EPP_DOMAINTRNDATA_H

/** @file epp_DomainTrnData.h
 *  @brief Definition of epp_DomainTrnData and epp_DomainTrnData_ref
 *  @author Asbjorn Steira Mikkelsen
 */

#include "epp_eppdata.h"
#include "epp_PollResData.h"

namespace eppobject { namespace domain {

   /// Class containing elements describing a domain transfer.
   /// @see epp_PollResData for additional information
   class epp_DomainTrnData : public eppobject::epp::epp_PollResData {
      
    public:
      eppobject::epp::epp_string_ref m_name; /**< Fully qualified name of the domain object */
      eppobject::epp::epp_TransferStatusType_ref m_transfer_status; /**< State of the most recent transfer request */
      eppobject::epp::epp_string_ref m_request_client_id; /**< ID of the client that requested the object transfer */
      eppobject::epp::epp_string_ref m_action_client_id; /**< ID of the client that should act upon the transfer request */
      eppobject::epp::epp_datetime_ref m_request_date; /**< Date and time that the transfer was requested */
      eppobject::epp::epp_datetime_ref m_action_date; /**< Date and time of a required or completed response */
      eppobject::epp::epp_datetime_ref m_expiration_date; /**< End of the domain object's validity period if the
							    * <transfer> command caused or causes a change in the
							    * validity period */
      
      /// Null constructor, setting #m_type
      epp_DomainTrnData()
	{
	   m_type = "domain:trnData";
	};
      
      /// Destructor
      virtual ~epp_DomainTrnData() {}
      
      /// Constructor, using simple types when it can, setting #m_type
      /// @note Cannot set simple types to NULL
      epp_DomainTrnData(const eppobject::epp::epp_string & _m_name,
			const eppobject::epp::epp_TransferStatusType & _m_transfer_status,
			const eppobject::epp::epp_string & _m_request_client_id,
			const eppobject::epp::epp_string & _m_action_client_id,
			const eppobject::epp::epp_datetime & _m_request_date,
			const eppobject::epp::epp_datetime & _m_action_date,
			const eppobject::epp::epp_datetime & _m_expiration_date)
	{
	   m_type = "domain:trnData";
	   
	   m_name.ref(new eppobject::epp::epp_string(_m_name));
	   m_transfer_status.ref(new eppobject::epp::epp_TransferStatusType(_m_transfer_status));
	   m_request_client_id.ref(new eppobject::epp::epp_string(_m_request_client_id));
	   m_action_client_id.ref(new eppobject::epp::epp_string(_m_action_client_id));
	   m_request_date.ref(new eppobject::epp::epp_datetime(_m_request_date));
	   m_action_date.ref(new eppobject::epp::epp_datetime(_m_action_date));
	   m_expiration_date.ref(new eppobject::epp::epp_datetime(_m_expiration_date));
	};
      
      /// Constructor, using only references, setting #m_type
      epp_DomainTrnData(const eppobject::epp::epp_string_ref & _m_name,
			const eppobject::epp::epp_TransferStatusType_ref & _m_transfer_status,
			const eppobject::epp::epp_string_ref & _m_request_client_id,
			const eppobject::epp::epp_string_ref & _m_action_client_id,
			const eppobject::epp::epp_datetime_ref & _m_request_date,
			const eppobject::epp::epp_datetime_ref & _m_action_date,
			const eppobject::epp::epp_datetime_ref & _m_expiration_date)
	{
	   m_type = "domain:trnData";

	   m_name = _m_name;
	   m_transfer_status = _m_transfer_status;
	   m_request_client_id = _m_request_client_id;
	   m_action_client_id = _m_action_client_id;
	   m_request_date = _m_request_date;
	   m_action_date = _m_action_date;
	   m_expiration_date = _m_expiration_date;
	};
      
      /// Returns the type of object
      /// @return Type of epp_PollResData object
      eppobject::epp::epp_string getType()
	{
	   return m_type;
	};
      
      /** Parses a trnData dom_ptr, fills in the public attributes of this class,
       *  and returns a ref to an #epp_PollResData object that is really an
       *  epp_DomainTrnData object
       * @param trnNode The trnData dom_ptr node
       * @return The corresponding epp_DomainTrnData object
       */
      eppobject::epp::epp_PollResData_ref createPollResData(const domtools::dom_ptr & trnNode);

   };
   
   /// Typedef for the ref to the epp_DomainTrnData class
   typedef refcnt_ptr<epp_DomainTrnData> epp_DomainTrnData_ref;
   
   /// Creates a pointer to an epp_DomainTrnData-object and returns it
   /// as an epp_PollResData pointer
   /// @return Pointer to an epp_DomainTrnData object
   static eppobject::epp::epp_PollResData * createDomainPollResData() {
      return new epp_DomainTrnData();
   }
   
}}

#endif
