/************************************************************************
 * EPP RTK C++
 * Copyright (C) 2001, 2002 The Global Name Registry, Limited 
 * 
 * This library is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published
 * by the Free Software Foundation; either version 2.1 of the License, or
 * (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact information:  epprtk@gnr.com
 *
 *                       EPP RTK
 *                       The Global Name Registry, Limited
 *                       125 High Holborn
 *                       London WC1V 6QA
 *                       United Kingdom
 ************************************************************************/

#ifndef __EPP_MESSAGEQUEUE_H
#define __EPP_MESSAGEQUEUE_H

/* $Header: /cvsroot/epp-rtk/epp-rtk/c++/src/data/epp_MessageQueue.h,v 1.7 2003/07/18 20:21:19 tubadanm Exp $ */

/** @file epp_MessageQueue.h
 *  @brief Definition of epp_MessageQueue and epp_MessageQueue_ref
 *  @author Asbjorn Steira Mikkelsen
 */

#include "epp_eppdata.h"
#include "epp_ExtMessage.h"

namespace eppobject { namespace epp {
   
   /// Class containing information about service messages queued for client retrieval
   class epp_MessageQueue {
      
    public:
      epp_long_ref m_count; /**< Number of service messages queued for client retrieval */
      epp_datetime_ref m_queue_date; /**< Date and time that a particular message was enqueued */
      epp_ExtMessage_ref m_msg; /**< The actual queued message */
      epp_string_ref m_id; /**< The ID of the returned message from the EPP server */

      /// Null constructor
      epp_MessageQueue() {};
      
      /// Destructor
      virtual ~epp_MessageQueue() {}

      /// Constructor, using simple types when it can
      /// @note Cannot set simple types to NULL
      epp_MessageQueue(const epp_long & _m_count,
		       const epp_datetime & _m_queue_date,
                       const epp_ExtMessage & _m_msg,
                       const epp_string & _m_id)
	{
	   m_count.ref(new epp_long(_m_count));
	   m_queue_date.ref(new epp_datetime(_m_queue_date));
           m_msg.ref(new epp_ExtMessage(_m_msg));
           m_id.ref(new epp_string(_m_id));
	};
      
      /// Constructor, using only references
      epp_MessageQueue(const epp_long_ref & _m_count,
		       const epp_datetime_ref & _m_queue_date,
                       const epp_ExtMessage_ref & _m_msg,
                       const epp_string_ref & _m_id)
	{
	   m_count = _m_count;
	   m_queue_date = _m_queue_date;
           m_msg = _m_msg;
           m_id = _m_id;
	};
   };
   /// Typedef for the ref to the epp_MessageQueue classe
   typedef refcnt_ptr<epp_MessageQueue> epp_MessageQueue_ref;
   std::ostream& operator<<(std::ostream &stream, const epp_MessageQueue_ref & msgq);
   std::ostream& operator<<(std::ostream &stream, const epp_MessageQueue & msgq);
   
}}

#endif
