/************************************************************************
 * EPP RTK C++
 * Copyright (C) 2001, 2002 The Global Name Registry, Limited 
 * 
 * This library is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published
 * by the Free Software Foundation; either version 2.1 of the License, or
 * (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact information:  epprtk@gnr.com
 *
 *                       EPP RTK
 *                       The Global Name Registry, Limited
 *                       125 High Holborn
 *                       London WC1V 6QA
 *                       United Kingdom
 ************************************************************************/

#ifndef __EPP_POLLRESDATAUNION_H
#define __EPP_POLLRESDATAUNION_H

/** @file epp_PollResDataUnion.h
 *  @brief Deprecated! Definition of epp_PollResDataUnion and epp_PollResDataUnion_ref
 *  @author Asbjorn Steira Mikkelsen
 *  @deprecated Functionality replaced by epp_PollResFactory.h from IDL 05/03
 */

#include "epp_eppdata.h"
#include "epp_DomainTrnData.h"
#include "epp_ContactTrnData.h"
#include "epp_XMLException.h"


namespace eppobject { namespace epp {
   
   /// Class containing the actual poll response data object
   /// @deprecated Functionality replaced by epp_PollResFactory from IDL 05/03
   class epp_PollResDataUnion {
      
    private:
      epp_PollResDataType_ref _disc; /**< Type of poll response data object */
      epp_DomainTrnData_ref _m_domain_transfer; /**< Domain transfer poll object */
      epp_ContactTrnData_ref _m_contact_transfer; /**< Contact transfer poll object */
      
    public:
      
      /// Null constructor
      epp_PollResDataUnion() {};
      
      /// Destructor
      virtual ~epp_PollResDataUnion() {};
      
      /// Copy constructor
      epp_PollResDataUnion(const epp_PollResDataUnion & u)
	{
	   switch(u._d()) {
	    case DOMAIN_TRANSFER:
	      _m_domain_transfer = u.m_domain_transfer();
	      break;
	    case CONTACT_TRANSFER:
	      _m_contact_transfer = u.m_contact_transfer();
	      break;
	    default:
	      break;
	   }
	   _disc = u._d();
	}
      
      /** Function to set the type of poll response data object
       * @param discriminant The poll response data object type
       */
      void _d(const epp_PollResDataType & discriminant)
	{
	   _disc.ref(new epp_PollResDataType(discriminant));
	}
      
      /** Function to return the type of poll response data object
       * @return The poll response data object type
       * @throw epp_XMLException If the object type has not been initialized
       */
      epp_PollResDataType _d() const
	{
	   if(_disc == NULL) {
	      throw epp_XMLException("epp_PollResDataUnion is not initialized");
	   }
	   return *_disc;
	}
      
      /** Function to return the domain transfer poll object
       * @return The domain transfer poll object
       * @throw epp_XMLException If the object type has not been initialized
       *                         or is of the wrong type
       */
      epp_DomainTrnData_ref m_domain_transfer() const
	{
	   if(_disc == NULL) {
	      throw epp_XMLException("epp_PollResDataUnion is not initialized");
	   }
	   
	   if(*_disc != DOMAIN_TRANSFER) {
	      throw epp_XMLException("epp_PollResDataUnion is not of type DOMAIN_TRANSFER");
	   }
	   
	   return _m_domain_transfer;
	}      
      
      /** Function to set the domain transfer poll object
       * @param param Domain transfer poll object
       */
      void m_domain_transfer(const epp_DomainTrnData_ref & param)
	{
	   _d(DOMAIN_TRANSFER);
	   _m_domain_transfer = param;
	}
      
      /** Function to return the contact transfer poll object
       * @return The contact transfer poll object
       * @throw epp_XMLException If the object type has not been initialized
       *                         or is of the wrong type
       */
      epp_ContactTrnData_ref m_contact_transfer() const
	{
	   if(_disc == NULL) {
	      throw epp_XMLException("epp_PollResDataUnion is not initialized");
	   }
	   
	   if(*_disc != CONTACT_TRANSFER) {
	      throw epp_XMLException("epp_PollResDataUnion is not of type CONTACT_TRANSFER");
	   }
	   
	   return _m_contact_transfer;
	}
      
      /** Function to set the contact transfer poll object
       * @param param The contact transfer poll object
       */
      void m_contact_transfer(const epp_ContactTrnData_ref & param)
	{
	   _d(CONTACT_TRANSFER);
	   _m_contact_transfer = param;
	}      

   };

   /// Typedef for the ref to the epp_PollResDataUnion class
   typedef refcnt_ptr<epp_PollResDataUnion> epp_PollResDataUnion_ref;
   
}}

#endif
