/************************************************************************
 * EPP RTK C++
 * Copyright (C) 2001, 2002 The Global Name Registry, Limited 
 * 
 * This library is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published
 * by the Free Software Foundation; either version 2.1 of the License, or
 * (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact information:  epprtk@gnr.com
 *
 *                       EPP RTK
 *                       The Global Name Registry, Limited
 *                       125 High Holborn
 *                       London WC1V 6QA
 *                       United Kingdom
 ************************************************************************/

#ifndef __EPP_RESULT_H
#define __EPP_RESULT_H

/* $Header: /cvsroot/epp-rtk/epp-rtk/c++/src/data/epp_Result.h,v 1.13 2003/07/18 20:21:19 tubadanm Exp $ */

/** @file epp_Result.h
 *  @brief Definition of epp_Result and epp_Result_ref
 *  @author Asbjorn Steira Mikkelsen
 */

#include "epp_eppdata.h"
#include "epp_ResultValue.h"
#include "epp_ExtResultValue.h"

namespace eppobject { namespace epp {
   
   /// Class containing elements used to describe success/failure of
   /// a command in server responses
   class epp_Result {
      
    public:
      
      epp_short_ref m_code; /**< Decimal number that describes the success or failure of the command */
      epp_resultvalue_seq_ref m_values; /**< The array of values that provide server error details.
                                             If null, m_ext_values should be checked. */
      epp_extresultvalue_seq_ref m_ext_values; /**< The array of values that provide server error details.
                                                    Can provide slightly more information than m_values (ie. reason for error).<br><br>
                                                    If empty, m_values should be checked. */
      epp_string_ref m_msg; /**< Human-readable description of the response code */
      epp_string_ref m_lang; /**< Language of the human-readable response (iso639) */
      
      /// Null constructor
      epp_Result() {};
      
      /// Destructor
      virtual ~epp_Result() {};
      
      /// Constructor, using simple types when it can
      /// @note Cannot set simple types to NULL
      epp_Result(const epp_short & _m_code,
		 const epp_resultvalue_seq_ref & _m_values,
		 const epp_extresultvalue_seq_ref & _m_ext_values,
		 const epp_string & _m_msg,
		 const epp_string & _m_lang)
	{
	   m_code.ref(new epp_short(_m_code));
	   m_values = _m_values;
	   m_ext_values = _m_ext_values;
	   m_msg.ref(new epp_string(_m_msg));
	   m_lang.ref(new epp_string(_m_lang));
	};
      
      /// Constructor, using only references
      epp_Result(const epp_short_ref & _m_code,
		 const epp_resultvalue_seq_ref & _m_values,
		 const epp_extresultvalue_seq_ref & _m_ext_values,
		 const epp_string_ref & _m_msg,
		 const epp_string_ref & _m_lang)
	{
	   m_code = _m_code;
	   m_values = _m_values;
	   m_ext_values = _m_ext_values;
	   m_msg = _m_msg;
	   m_lang = _m_lang;
	};
   };
   
   /// Typedef for the ref to the epp_Result class
   typedef refcnt_ptr<epp_Result> epp_Result_ref;
   std::ostream& operator<<(std::ostream &stream, const epp_Result_ref & result);
   std::ostream& operator<<(std::ostream &stream, const epp_Result & result);
   
}}

#endif
