/************************************************************************
 * EPP RTK C++
 * Copyright (C) 2001, 2002 The Global Name Registry, Limited 
 * 
 * This library is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published
 * by the Free Software Foundation; either version 2.1 of the License, or
 * (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact information:  epprtk@gnr.com
 *
 *                       EPP RTK
 *                       The Global Name Registry, Limited
 *                       125 High Holborn
 *                       London WC1V 6QA
 *                       United Kingdom
 ************************************************************************/

#ifndef __EPP_RESULT_VALUE_H
#define __EPP_RESULT_VALUE_H

/* $Header: /cvsroot/epp-rtk/epp-rtk/c++/src/data/epp_ResultValue.h,v 1.3 2003/07/18 20:21:19 tubadanm Exp $ */

/** @file epp_ResultValue.h
 *  @brief Definition of epp_ResultValue and epp_ResultValue_ref
 *  @author Daniel Manley
 */

#include "epp_eppdata.h"

namespace eppobject { namespace epp {
   
   /// Class containing elements used to describe success/failure of
   /// a command in server responses
   class epp_ResultValue {
      
    public:
      
      epp_string_ref m_namespace; /**< Client-provided values that caused server error conditions */
      epp_xml_string_ref m_xml_string; /**< Human-readable description of the response code */
      epp_string_ref m_element_name; /**< Language of the human-readable response (iso639) */
      epp_string_ref m_element_value; /**< ID to uniquely identify the message returned (used for the Poll command) */
      
      /// Null constructor
      epp_ResultValue() {};
      
      /// Destructor
      virtual ~epp_ResultValue() {};
      
      /// Constructor, using simple types when it can
      /// @note Cannot set simple types to NULL
      epp_ResultValue(const epp_string & _m_namespace,
		      const epp_xml_string & _m_xml_string,
		      const epp_string & _m_element_name,
		      const epp_string & _m_element_value)
	{
	   m_namespace.ref(new epp_string(_m_namespace));
	   m_xml_string.ref(new epp_xml_string(_m_xml_string));
	   m_element_name.ref(new epp_string(_m_element_name));
	   m_element_value.ref(new epp_string(_m_element_value));
	};
      
      /// Constructor, using only references
      epp_ResultValue(const epp_string_ref & _m_namespace,
		      const epp_xml_string_ref & _m_xml_string,
		      const epp_string_ref & _m_element_name,
		      const epp_string_ref & _m_element_value)
	{
	   m_namespace = _m_namespace;
	   m_xml_string = _m_xml_string;
	   m_element_name = _m_element_name;
	   m_element_value = _m_element_value;
	};
   };
   
   /// Typedef for the ref to the epp_ResultValue class
   typedef refcnt_ptr<epp_ResultValue> epp_ResultValue_ref;
   std::ostream& operator<<(std::ostream &stream, const epp_ResultValue_ref & resvalue);
   std::ostream& operator<<(std::ostream &stream, const epp_ResultValue & resvalue);
   
}}

#endif
