/************************************************************************
 * EPP RTK C++
 * Copyright (C) 2001, 2002 The Global Name Registry, Limited 
 * 
 * This library is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published
 * by the Free Software Foundation; either version 2.1 of the License, or
 * (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact information:  epprtk@gnr.com
 *
 *                       EPP RTK
 *                       The Global Name Registry, Limited
 *                       125 High Holborn
 *                       London WC1V 6QA
 *                       United Kingdom
 ************************************************************************/

#ifndef __EPP_TRANSFERREQUEST_H
#define __EPP_TRANSFERREQUEST_H

/** @file epp_TransferRequest.h
 *  @brief Definition of epp_TransferRequest and epp_TransferRequest_ref
 *  @author Asbjorn Steira Mikkelsen
 */

#include "epp_eppdata.h"
#include "epp_AuthInfo.h"

namespace eppobject { namespace epp {

   /// Class containing common elements used in transfer requests
   class epp_TransferRequest {
      
    public:
      epp_AuthInfo_ref m_auth_info; /**< Authorization information associated with the object */
      epp_TransferOpType_ref m_op; /**< Transfer operation to be performed */

      /// Null constructor
      epp_TransferRequest() {};
      
      /// Destructor
      virtual ~epp_TransferRequest() {};
      
      /// Constructor, using simple types when it can
      /// @note Cannot set simple types to NULL
      epp_TransferRequest(const epp_AuthInfo_ref & _m_auth_info,
			  const epp_TransferOpType & _m_op)
	{
	   m_auth_info = _m_auth_info;
	   m_op.ref(new epp_TransferOpType(_m_op));
	};
      
      /// Constructor, using only references
      epp_TransferRequest(const epp_AuthInfo_ref & _m_auth_info,
			  const epp_TransferOpType_ref & _m_op)
	{
	   m_auth_info = _m_auth_info;
	   m_op = _m_op;
	};
   };
   
   /// Typedef for the ref to the epp_TransferRequest class
   typedef refcnt_ptr<epp_TransferRequest> epp_TransferRequest_ref;
   
}}

#endif
