/************************************************************************
 * EPP RTK C++
 * Copyright (C) 2001, 2002 The Global Name Registry, Limited 
 * 
 * This library is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published
 * by the Free Software Foundation; either version 2.1 of the License, or
 * (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact information:  epprtk@gnr.com
 *
 *                       EPP RTK
 *                       The Global Name Registry, Limited
 *                       125 High Holborn
 *                       London WC1V 6QA
 *                       United Kingdom
 ************************************************************************/

#ifndef __EPP_CONTACTDATA_H
#define __EPP_CONTACTDATA_H

/* $Header: /cvsroot/epp-rtk/epp-rtk/c++/src/data/epp_contactdata.h,v 1.11 2003/07/18 20:21:19 tubadanm Exp $ */

/** @file epp_contactdata.h
 *  @brief Declaration of enums/typedefs used in contact objects
 *  @author Asbjorn Steira Mikkelsen
 */

#include "epp_eppdata.h"
#include <vector>


namespace eppobject { namespace contact {
   
      /******************************************
       *                                        *
       *              Enumerations              *
       *                                        *
       ******************************************/

   /// Status types allowed for a contact object
   enum epp_ContactStatusType {
      CLIENT_DELETE_PROHIBITED,
      SERVER_DELETE_PROHIBITED,
      CLIENT_TRANSFER_PROHIBITED,
      SERVER_TRANSFER_PROHIBITED,
      CLIENT_UPDATE_PROHIBITED,
      SERVER_UPDATE_PROHIBITED,
      LINKED,
      OK,
      PENDING_CREATE,
      PENDING_DELETE,
      PENDING_TRANSFER,
      PENDING_UPDATE
   };
   
   /// Typedef for the ref to the #epp_ContactStatusType enum
   typedef refcnt_ptr<epp_ContactStatusType> epp_ContactStatusType_ref;
   
   
   /// Postal Info types allowed for a contact object
   enum epp_ContactPostalInfoType {
      LOC,
      INT
   };
   
   /// Typedef for the ref to the #epp_ContactPostalInfoType enum
   typedef refcnt_ptr<epp_ContactPostalInfoType> epp_ContactPostalInfoType_ref;
   
   
   /******************************************
    *                                        *
    *              Pure typedefs             *
    *                                        *
    ******************************************/
   
   class epp_ContactStatus; //Forward declaration...
   
   /// Typedef for a sequence of #epp_ContactStatus elements
   typedef std::vector<epp_ContactStatus> epp_contact_status_seq;
   
   /// Typedef for the ref to #epp_contact_status_seq
   typedef refcnt_ptr<epp_contact_status_seq> epp_contact_status_seq_ref;
   
}}
#endif
