/************************************************************************
 * EPP RTK C++
 * Copyright (C) 2001, 2002 The Global Name Registry, Limited 
 * 
 * This library is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published
 * by the Free Software Foundation; either version 2.1 of the License, or
 * (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact information:  epprtk@gnr.com
 *
 *                       EPP RTK
 *                       The Global Name Registry, Limited
 *                       125 High Holborn
 *                       London WC1V 6QA
 *                       United Kingdom
 ************************************************************************/

#ifndef __EPP_DCPSTATEMENT_H
#define __EPP_DCPSTATEMENT_H

/** @file epp_dcpStatement.h
 *  @brief Definition of epp_dcpStatement and epp_dcpStatement_ref
 *  @author Asbjorn Steira Mikkelsen
 */

#include "epp_eppdata.h"
#include "epp_dcpRecipient.h"

namespace eppobject { namespace epp {

   /// Class containing elements used to describe the server's policy for data
   /// collection purposes, data recipients, and data retention
   class epp_dcpStatement {
      
    public:
      epp_dcpPurpose_seq_ref m_purposes; /**< Data collection purpose */
      epp_dcpRecipient_seq_ref m_recipients; /**< Data recipient */
      epp_dcpRetentionType_ref m_retention; /**< Data retention */
      
      /// Null constructor
      epp_dcpStatement() {};
      
      /// Destructor
      virtual ~epp_dcpStatement() {}
      
      /// Constructor, using only references
      epp_dcpStatement(const epp_dcpPurpose_seq_ref & _m_purposes,
		       const epp_dcpRecipient_seq_ref & _m_recipients,
		       const epp_dcpRetentionType_ref & _m_retention)
	{
	   m_purposes = _m_purposes;
	   m_recipients = _m_recipients;
	   m_retention = _m_retention;
	};
   };
   
   /// Typedef for the ref to the epp_dcpStatement class
   typedef refcnt_ptr<epp_dcpStatement> epp_dcpStatement_ref;
   
}}

#endif
