/************************************************************************
 * EPP RTK C++
 * Copyright (C) 2001, 2002 The Global Name Registry, Limited 
 * 
 * This library is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published
 * by the Free Software Foundation; either version 2.1 of the License, or
 * (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact information:  epprtk@gnr.com
 *
 *                       EPP RTK
 *                       The Global Name Registry, Limited
 *                       125 High Holborn
 *                       London WC1V 6QA
 *                       United Kingdom
 ************************************************************************/

/** @file epp_domainXMLbase.cc
 *  @brief Definition of XML helper-functions for domain objects
 *  @author Asbjorn Steira Mikkelsen
 *  @see epp_domainXMLbase.h
 */

#include "epp_domainXMLbase.h"
#include <map>
#include "epp_XMLException.h"

using namespace std;
using namespace domtools;
using namespace eppobject::domain;
using namespace eppobject::epp;


void eppobject::domain::setCommandSchemaAttributes(eppobject::epp::EPP_output & outputobject)
{
   outputobject.putAttribute("xmlns:domain","urn:ietf:params:xml:ns:domain-1.0");
   outputobject.putAttribute("xsi:schemaLocation","urn:ietf:params:xml:ns:domain-1.0 domain-1.0.xsd");
};


eppobject::epp::epp_string eppobject::domain::returnPeriodUnitType(const epp_DomainPeriodUnitType & unittype)
{
   map<epp_DomainPeriodUnitType, epp_string> unitMap;
   
   unitMap[YEAR] = "y";
   unitMap[MONTH] = "m";
   
   if(unitMap.find(unittype) == unitMap.end()) {
      throw epp_XMLException(__FILE__, __LINE__, "Unknown DomainPeriodType");
   }
   
   return unitMap[unittype];
};


eppobject::epp::epp_string eppobject::domain::returnContactType(const epp_DomainContactType & contacttype)
{
   map<epp_DomainContactType, epp_string> contactMap;
   
   contactMap[ADMIN] = "admin";
   contactMap[BILLING] = "billing";
   contactMap[TECH] = "tech";
   
   if(contactMap.find(contacttype) == contactMap.end()) {
      throw epp_XMLException(__FILE__, __LINE__, "Unknown DomainContactType");
   }
   
   return contactMap[contacttype];
}


epp_DomainContactType eppobject::domain::returnContactEnumType(const eppobject::epp::epp_string & contacttype)
{
   map<epp_string, epp_DomainContactType> contactMap;
   
   contactMap["admin"] = ADMIN;
   contactMap["billing"] = BILLING;
   contactMap["tech"] = TECH;
   
   if(contactMap.find(contacttype) == contactMap.end()) {
      throw epp_XMLException(__FILE__, __LINE__, "Unknown DomainContactType");
   }
   
   return contactMap[contacttype];   
}


eppobject::epp::epp_string eppobject::domain::returnStatusType(const epp_DomainStatusType & statusType)
{
   map<epp_DomainStatusType, string> domainStatusTypeMap;
   
   domainStatusTypeMap[CLIENT_DELETE_PROHIBITED] = "clientDeleteProhibited";
   domainStatusTypeMap[CLIENT_HOLD] = "clientHold";
   domainStatusTypeMap[CLIENT_RENEW_PROHIBITED] = "clientRenewProhibited";
   domainStatusTypeMap[CLIENT_TRANSFER_PROHIBITED] = "clientTransferProhibited";
   domainStatusTypeMap[CLIENT_UPDATE_PROHIBITED] = "clientUpdateProhibited";
   domainStatusTypeMap[INACTIVE] = "inactive";
   domainStatusTypeMap[OK] = "ok";
   domainStatusTypeMap[PENDING_CREATE] = "pendingCreate";
   domainStatusTypeMap[PENDING_DELETE] = "pendingDelete";
   domainStatusTypeMap[PENDING_TRANSFER] = "pendingTransfer";
   domainStatusTypeMap[PENDING_RENEW] = "pendingRenew";
   domainStatusTypeMap[PENDING_UPDATE] = "pendingUpdate";
   domainStatusTypeMap[SERVER_DELETE_PROHIBITED] = "serverDeleteProhibited";
   domainStatusTypeMap[SERVER_HOLD] = "serverHold";
   domainStatusTypeMap[SERVER_RENEW_PROHIBITED] = "serverRenewProhibited";
   domainStatusTypeMap[SERVER_TRANSFER_PROHIBITED] = "serverTransferProhibited";
   domainStatusTypeMap[SERVER_UPDATE_PROHIBITED] = "serverUpdateProhibited";
   
   if(domainStatusTypeMap.find(statusType) == domainStatusTypeMap.end()) {
      throw epp_XMLException(__FILE__, __LINE__, "Unknown DomainStatusType");
   }
   
   return domainStatusTypeMap[statusType];
}


epp_DomainStatusType eppobject::domain::returnStatusEnumType(const eppobject::epp::epp_string & statusType)
{
   map<epp_string, epp_DomainStatusType> domainStatusTypeMap;
   
   domainStatusTypeMap["clientDeleteProhibited"] = CLIENT_DELETE_PROHIBITED;
   domainStatusTypeMap["clientHold"] = CLIENT_HOLD;
   domainStatusTypeMap["clientRenewProhibited"] = CLIENT_RENEW_PROHIBITED;
   domainStatusTypeMap["clientTransferProhibited"] = CLIENT_TRANSFER_PROHIBITED;
   domainStatusTypeMap["clientUpdateProhibited"] = CLIENT_UPDATE_PROHIBITED;
   domainStatusTypeMap["inactive"] = INACTIVE;
   domainStatusTypeMap["ok"] = OK;
   domainStatusTypeMap["pendingCreate"] = PENDING_CREATE;
   domainStatusTypeMap["pendingDelete"] = PENDING_DELETE;
   domainStatusTypeMap["pendingTransfer"] = PENDING_TRANSFER;
   domainStatusTypeMap["pendingRenew"] = PENDING_RENEW;
   domainStatusTypeMap["pendingUpdate"] = PENDING_UPDATE;
   domainStatusTypeMap["serverDeleteProhibited"] = SERVER_DELETE_PROHIBITED;
   domainStatusTypeMap["serverHold"] = SERVER_HOLD;
   domainStatusTypeMap["serverRenewProhibited"] = SERVER_RENEW_PROHIBITED;
   domainStatusTypeMap["serverTransferProhibited"] = SERVER_TRANSFER_PROHIBITED;
   domainStatusTypeMap["serverUpdateProhibited"] = SERVER_UPDATE_PROHIBITED;
   
   if(domainStatusTypeMap.find(statusType) == domainStatusTypeMap.end()) {
      throw epp_XMLException(__FILE__, __LINE__, "Unknown DomainStatusType");
   }
   
   return domainStatusTypeMap[statusType];
}

epp_DomainHostsType eppobject::domain::returnDomainHostsEnumType(const eppobject::epp::epp_string & hostsType)
{
   map<epp_string, epp_DomainHostsType> domainHostsTypeMap;
   
   domainHostsTypeMap["all"] = ALL;
   domainHostsTypeMap["del"] = DEL;
   domainHostsTypeMap["none"] = NONE;
   domainHostsTypeMap["sub"] = SUB;
   
   if(domainHostsTypeMap.find(hostsType) == domainHostsTypeMap.end()) {
      throw epp_XMLException(__FILE__, __LINE__, "Unknown DomainHostsType");
   }
   
   return domainHostsTypeMap[hostsType];
}

eppobject::epp::epp_string eppobject::domain::returnDomainHostsType(const epp_DomainHostsType & hostsType)
{
   map<epp_DomainHostsType, epp_string> domainHostsTypeMap;
   
   domainHostsTypeMap[ALL] = "all";
   domainHostsTypeMap[DEL] = "del";
   domainHostsTypeMap[NONE] = "none";
   domainHostsTypeMap[SUB] = "sub";
   
   if(domainHostsTypeMap.find(hostsType) == domainHostsTypeMap.end()) {
      throw epp_XMLException(__FILE__, __LINE__, "Unknown DomainHostsType");
   }
   
   return domainHostsTypeMap[hostsType];
}
