/************************************************************************
 * EPP RTK C++
 * Copyright (C) 2001, 2002 The Global Name Registry, Limited 
 * 
 * This library is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published
 * by the Free Software Foundation; either version 2.1 of the License, or
 * (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact information:  epprtk@gnr.com
 *
 *                       EPP RTK
 *                       The Global Name Registry, Limited
 *                       125 High Holborn
 *                       London WC1V 6QA
 *                       United Kingdom
 ************************************************************************/

#ifndef __EPP_EPPDATA_H
#define __EPP_EPPDATA_H

/* $Header: /cvsroot/epp-rtk/epp-rtk/c++/src/data/epp_eppdata.h,v 1.15 2003/07/18 20:21:19 tubadanm Exp $ */

/** @file epp_eppdata.h
 *  @brief Declaration of common/generic enums/typedefs used in the RTK
 *  @author Asbjorn Steira Mikkelsen
 */

#include <string>
#include <vector>
#include <domtools/refcount.h>

namespace eppobject { namespace epp {   

   /******************************************
    *                                        *
    *              Enumerations              *
    *                                        *
    ******************************************/
   
   /// Allowed transfer operations
   enum epp_TransferOpType {
      APPROVE,
      CANCEL,
      QUERY,
      REJECT,
      REQUEST
   };
   
   /// Typedef for the ref to the #epp_TransferOpType enum
   typedef refcnt_ptr<epp_TransferOpType> epp_TransferOpType_ref;
   
   /// Transfer state of an object
   enum epp_TransferStatusType {
      CLIENT_APPROVED,
      CLIENT_CANCELLED,
      CLIENT_REJECTED,
      PENDING,
      SERVER_APPROVED,
      SERVER_CANCELLED
   };
   
   /// Typedef for the ref to the #epp_TransferStatusType enum
   typedef refcnt_ptr<epp_TransferStatusType> epp_TransferStatusType_ref;
   
   /// Operation type for poll command
   enum epp_PollOpType {
      ACK,
      REQ
   };
   
   /// Typedef for the ref to the #epp_PollOpType enum
   typedef refcnt_ptr<epp_PollOpType> epp_PollOpType_ref;
   
   /// Authorization information type
   enum epp_AuthInfoType {
      PW,
      EXT
   };
   
   /// Typedef for the ref to the #epp_AuthInfoType enum
   typedef refcnt_ptr<epp_AuthInfoType> epp_AuthInfoType_ref;
   
   /// Allowed result data types in a poll command
   /// @deprecated Not needed anymore from IDL 05/03
   enum epp_PollResDataType
     {
	DOMAIN_TRANSFER,
	CONTACT_TRANSFER
	  /* and whatever poll response types there might be */
     };
   
   /// Typedef for the ref to the #epp_PollResDataType enum
   typedef refcnt_ptr<epp_PollResDataType> epp_PollResDataType_ref;

   
   // Types used in Data Collection Policity Specifications:
   
   /// Access types provided by the server to data received from the client
   enum epp_dcpAccessType
     {
	ALL,
	NONE_ACCESS,  // Appended "_ACCESS" to solve name conflict...
	NULL_ACCESS, // Appended "_ACCESS" to work in C++
	OTHER,
        PERSONAL,
        PERSONAL_AND_OTHER
     };
   
   /// Typedef for the ref to the #epp_dcpAccessType enum
   typedef refcnt_ptr<epp_dcpAccessType> epp_dcpAccessType_ref;
   
   /// Data collection purpose types
   enum epp_dcpPurposeType
     {
	ADMIN_PURPOSE,
        CONTACT,
	OTHER_PURPOSE, // Appended "_PURPOSE" to solve name conflict...
	PROV
     };
   
   /// Typedef for the ref to the #epp_dcpPurposeType enum
   typedef refcnt_ptr<epp_dcpPurposeType> epp_dcpPurposeType_ref;
   
   /// Data collection recipient types
   enum epp_dcpRecipientType
     {
	OTHER_RECIPIENT, // Appended "_RECIPIENT" to solve name conflict....
	OURS,
	PUBLIK, // "PUBLIC" is a reserved word...
	SAME,
	UNRELATED
     };
   
   /// Typedef for the ref to the #epp_dcpRecipientType enum
   typedef refcnt_ptr<epp_dcpRecipientType> epp_dcpRecipientType_ref;
   
   /// Data collection retention types
   enum epp_dcpRetentionType
     {
	BUSINESS,
        INDEFINITE,
        LEGAL,
        NONE,
        STATED
     };
   
   /// Typedef for the ref to the #epp_dcpRetentionType enum
   typedef refcnt_ptr<epp_dcpRetentionType> epp_dcpRetentionType_ref;
   
   enum epp_dcpExpiryType {
        ABSOLUTE,
        RELATIVE
     };
    
   /// Typedef for the ref to the #epp_dcpRetentionType enum
   typedef refcnt_ptr<epp_dcpExpiryType> epp_dcpExpiryType_ref;
   

   /// Typedef for a sequence of #epp_dcpPurposeType elements
   typedef std::vector<epp_dcpPurposeType> epp_dcpPurpose_seq;
   
   /// Typedef for the ref to the #epp_dcpPurpose_seq element
   typedef refcnt_ptr<epp_dcpPurpose_seq> epp_dcpPurpose_seq_ref;
   
   /******************************************
    *                                        *
    *              Pure typedefs             *
    *                                        *
    ******************************************/
   
   /// Defining epp_string to be of type string
   typedef std::string epp_string;
   
   /// Typedef for the ref to #epp_string
   typedef refcnt_ptr<epp_string> epp_string_ref;
   
   /// Typedef for a sequence of epp_strings
   typedef std::vector<epp_string> epp_string_seq;
    
   /// Typedef for the ref to the #epp_string_seq element
   typedef refcnt_ptr<epp_string_seq> epp_string_seq_ref;
   
   /// Defining epp_xml_string to be of type string
   typedef std::string epp_xml_string;
   
   /// Typedef for the ref to #epp_xml_string
   typedef refcnt_ptr<epp_xml_string> epp_xml_string_ref;
   
   /// Typedef for a sequence of epp_strings
   typedef std::vector<epp_xml_string> epp_xml_string_seq;
    
   /// Typedef for the ref to the #epp_xml_string_seq element
   typedef refcnt_ptr<epp_xml_string_seq> epp_xml_string_seq_ref;
   
   /// Defining epp_short to be of type short
   typedef short epp_short;
   
   /// Typedef for the ref to #epp_short
   typedef refcnt_ptr<epp_short> epp_short_ref;
   
   /// Defining epp_long to be of type long
   typedef long epp_long;

   /// Typedef for the ref to #epp_long
   typedef refcnt_ptr<epp_long> epp_long_ref;
   
   /// Defining epp_boolean to be of type bool
   typedef bool epp_boolean;
   
   /// Typedef for the ref to #epp_boolean
   typedef refcnt_ptr<epp_boolean> epp_boolean_ref;
   
   /// Defining epp_any to be a void pointer
   typedef void* epp_any;
   
   /// Typedef for the ref to #epp_any
   typedef refcnt_ptr<epp_any> epp_any_ref;
   
   /// Defining epp_date to be of type string
   typedef std::string epp_date;

   /// Typedef for the ref to #epp_date
   typedef refcnt_ptr<epp_date> epp_date_ref;
   
   /// Defining epp_datetime to be of type string
   typedef std::string epp_datetime;
   
   /// Typedef for the ref to #epp_datetime
   typedef refcnt_ptr<epp_datetime> epp_datetime_ref;
   
   /// Defining epp_trid to be of type #epp_string
   typedef epp_string epp_trid;
   
   /// Typedef for the ref to #epp_trid
   typedef refcnt_ptr<epp_trid> epp_trid_ref;
   
   /// Defining epp_roid to be of type #epp_string
   typedef epp_string epp_roid;
   
   /// Typedef for the ref to #epp_roid
   typedef refcnt_ptr<epp_roid> epp_roid_ref;
   
   /// Typedef for a sequence of epp_roids
   typedef std::vector<epp_roid> epp_roid_seq;
   
   /// Typedef for the ref to #epp_roid_seq element
   typedef refcnt_ptr<epp_roid_seq> epp_roid_seq_ref;
   
   class epp_Result; // Forward declaration...

   /// Typedef for a sequence of #epp_Result elements
   typedef std::vector<epp_Result> epp_result_seq;
   
   /// Typedef for the ref to #epp_result_seq
   typedef refcnt_ptr<epp_result_seq> epp_result_seq_ref;
   
   class epp_ResultValue; // Forward declaration...

   /// Typedef for a sequence of #epp_ResultValue elements
   typedef std::vector<epp_ResultValue> epp_resultvalue_seq;
   
   /// Typedef for the ref to #epp_result_seq
   typedef refcnt_ptr<epp_resultvalue_seq> epp_resultvalue_seq_ref;
   

   class epp_ExtResultValue; // Forward declaration...

   /// Typedef for a sequence of #epp_ExtResultValue elements
   typedef std::vector<epp_ExtResultValue> epp_extresultvalue_seq;
   
   /// Typedef for the ref to #epp_result_seq
   typedef refcnt_ptr<epp_extresultvalue_seq> epp_extresultvalue_seq_ref;

   
   class epp_Extension; // Forward declaration...
   typedef refcnt_ptr<epp_Extension> epp_Extension_ref;
   
   /// Typedef for a sequence of #epp_Extension elements
   typedef std::vector<epp_Extension> epp_extension_seq;
   
   /// Typedef for the ref to #epp_extension_seq
   typedef refcnt_ptr<epp_extension_seq> epp_extension_seq_ref;

   /* XXX DANDAN might this cause memory leaks??? */
   /// Typedef for a sequence of #epp_Extension_ref elements
   typedef std::vector<epp_Extension_ref> epp_extension_ref_seq;
   
   /// Typedef for the ref to #epp_extension_ref_seq
   typedef refcnt_ptr<epp_extension_ref_seq> epp_extension_ref_seq_ref;

   
   class epp_Service; // Forward declaration...
   
   /// Typedef for a sequence of #epp_Service elements
   /// @deprecated From EPP/IDL 05/03 replaced by usage of #epp_string
   typedef std::vector<epp_Service> epp_service_seq;   
   
   /// Typedef for the ref to #epp_service_seq
   typedef refcnt_ptr<epp_service_seq> epp_service_seq_ref;


   class epp_CheckResult; // Forward declaration...
   
   /// Typedef for a sequence of #epp_CheckResult elements
   typedef std::vector<epp_CheckResult> epp_check_result_seq;
   
   /// Typedef for the ref to #epp_check_result_seq
   typedef refcnt_ptr<epp_check_result_seq> epp_check_result_seq_ref;


   class epp_dcpRecipient; // Forward declaration...
   
   /// Typedef for a sequence of #epp_dcpRecipient elements
   typedef std::vector<epp_dcpRecipient> epp_dcpRecipient_seq;
   
   /// Typedef for the ref to #epp_dcprecipient_seq
   typedef refcnt_ptr<epp_dcpRecipient_seq> epp_dcpRecipient_seq_ref;


   /// Defining a sequence of epp_objuri elements to be of type #epp_string_seq
   typedef epp_string_seq epp_objuri_seq;
   
   /// Typedef for the ref to #epp_objuri_seq
   typedef refcnt_ptr<epp_objuri_seq> epp_objuri_seq_ref;
   
   /// Defining a sequence of epp_exturi elements to be of type #epp_string_seq
   typedef epp_string_seq epp_exturi_seq;
   
   /// Typedef for the ref to #epp_exturi_seq
   typedef refcnt_ptr<epp_exturi_seq> epp_exturi_seq_ref;
   
   class epp_dcpStatement; // Forward declaration...
   
   /// Typedef for a sequence of #epp_dcpStatement elements
   typedef std::vector<epp_dcpStatement> epp_dcpStatement_seq;
   
   /// Typedef for the ref to #epp_dcpStatement_seq
   typedef refcnt_ptr<epp_dcpStatement_seq> epp_dcpStatement_seq_ref;
}}

#endif
