/************************************************************************
 * EPP RTK C++
 * Copyright (C) 2001, 2002 The Global Name Registry, Limited 
 * 
 * This library is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published
 * by the Free Software Foundation; either version 2.1 of the License, or
 * (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact information:  epprtk@gnr.com
 *
 *                       EPP RTK
 *                       The Global Name Registry, Limited
 *                       125 High Holborn
 *                       London WC1V 6QA
 *                       United Kingdom
 ************************************************************************/

/** @file epp_hostXMLbase.cc
 *  @brief Definition of XML helper-functions for host objects
 *  @author Asbjorn Steira Mikkelsen
 *  @see epp_hostXMLbase.h
 */

#include "epp_hostXMLbase.h"
#include "epp_XMLException.h"
#include <map>

using namespace std;
using namespace domtools;
using namespace eppobject::host;
using namespace eppobject::epp;


void eppobject::host::setCommandSchemaAttributes(eppobject::epp::EPP_output & outputobject)
{
   outputobject.putAttribute("xmlns:host","urn:ietf:params:xml:ns:host-1.0");
   outputobject.putAttribute("xsi:schemaLocation","urn:ietf:params:xml:ns:host-1.0 host-1.0.xsd");
};


eppobject::epp::epp_string eppobject::host::returnIPTypeString(const epp_HostAddressType & IPType)
{
   map<epp_HostAddressType, epp_string> ipTypeMap;

   ipTypeMap[IPV4] = "v4";
   ipTypeMap[IPV6] = "v6";
   
   if(ipTypeMap.find(IPType) == ipTypeMap.end()) {
      throw epp_XMLException(__FILE__, __LINE__, "Unknown HostAddressType");
   }
   
   return ipTypeMap[IPType];
};


eppobject::epp::epp_string eppobject::host::returnStatusType(const epp_HostStatusType & statusType)
{
   map<epp_HostStatusType, epp_string> hostStatusTypeMap;
   
   hostStatusTypeMap[CLIENT_DELETE_PROHIBITED] = "clientDeleteProhibited";
   hostStatusTypeMap[CLIENT_UPDATE_PROHIBITED] = "clientUpdateProhibited";
   hostStatusTypeMap[LINKED] = "linked";
   hostStatusTypeMap[OK] = "ok";
   hostStatusTypeMap[PENDING_CREATE] = "pendingCreate";
   hostStatusTypeMap[PENDING_DELETE] = "pendingDelete";
   hostStatusTypeMap[PENDING_TRANSFER] = "pendingTransfer";
   hostStatusTypeMap[PENDING_UPDATE] = "pendingUpdate";
   hostStatusTypeMap[SERVER_DELETE_PROHIBITED] = "serverDeleteProhibited";
   hostStatusTypeMap[SERVER_UPDATE_PROHIBITED] = "serverUpdateProhibited";
   
   if(hostStatusTypeMap.find(statusType) == hostStatusTypeMap.end()) {
      throw epp_XMLException(__FILE__, __LINE__, "Unknown HostStatusType");
   }

   return hostStatusTypeMap[statusType];
};


epp_HostStatusType eppobject::host::returnStatusEnumType(const eppobject::epp::epp_string & statusType)
{
   map<epp_string, epp_HostStatusType> hostStatusTypeMap;
   
   hostStatusTypeMap["clientDeleteProhibited"] = CLIENT_DELETE_PROHIBITED;
   hostStatusTypeMap["clientUpdateProhibited"] = CLIENT_UPDATE_PROHIBITED;
   hostStatusTypeMap["linked"] = LINKED;
   hostStatusTypeMap["ok"] = OK;
   hostStatusTypeMap["pendingCreate"] = PENDING_CREATE;
   hostStatusTypeMap["pendingDelete"] = PENDING_DELETE;
   hostStatusTypeMap["pendingTransfer"] = PENDING_TRANSFER;
   hostStatusTypeMap["pendingUpdate"] = PENDING_UPDATE;
   hostStatusTypeMap["serverDeleteProhibited"] = SERVER_DELETE_PROHIBITED;
   hostStatusTypeMap["serverUpdateProhibited"] = SERVER_UPDATE_PROHIBITED;
   
   if(hostStatusTypeMap.find(statusType) == hostStatusTypeMap.end()) {
      throw epp_XMLException(__FILE__, __LINE__, "Unknown HostStatusType");
   }
   
   return hostStatusTypeMap[statusType];
}


epp_HostAddressType eppobject::host::returnIPTypeEnum(const eppobject::epp::epp_string & IPType)
{
   map<epp_string, epp_HostAddressType> ipTypeMap;

   ipTypeMap["v4"] = IPV4;
   ipTypeMap["v6"] = IPV6;
   
   if(ipTypeMap.find(IPType) == ipTypeMap.end()) {
      throw epp_XMLException(__FILE__, __LINE__, "Unknown HostAddressType");
   }
   
   return ipTypeMap[IPType];   
}
