/************************************************************************
 * EPP RTK C++
 * Copyright (C) 2001, 2002 The Global Name Registry, Limited 
 * 
 * This library is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published
 * by the Free Software Foundation; either version 2.1 of the License, or
 * (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact information:  epprtk@gnr.com
 *
 *                       EPP RTK
 *                       The Global Name Registry, Limited
 *                       125 High Holborn
 *                       London WC1V 6QA
 *                       United Kingdom
 ************************************************************************/

#ifndef __EPP_HOSTXMLBASE_H
#define __EPP_HOSTXMLBASE_H

/** @file epp_hostXMLbase.h
 *  @brief Declaration of XML helper-functions for host objects
 *  @author Asbjorn Steira Mikkelsen
 */

#include "epp_hostdata.h"
#include "epp_eppXMLbase.h"


namespace eppobject { namespace host {
   
   /** Writes attributes that identify the host namespace and the location 
    *  of the host schema to the output object
    * @param outputobject The output object to write to
    */
   void setCommandSchemaAttributes(eppobject::epp::EPP_output & outputobject);
   
   /** Returns the corresponsing epp_string text for the given epp_HostAddressType-enum
    * @param IPType The IP type as an epp_HostAddressType-enum
    * @return The IP type as an epp_string
    * @throw epp_XMLException If IPType is not a valid epp_HostAddressType
    */
   eppobject::epp::epp_string returnIPTypeString(const epp_HostAddressType & IPType);
   
   /** Returns the corresponsing epp_HostAddressType for the given epp_string
    * @param IPType The IP type as an epp_string
    * @return The IP type as an epp_HostAddressType-enum
    * @throw epp_XMLException If IPType is not a valid epp_HostAddressType
    */
   epp_HostAddressType returnIPTypeEnum(const eppobject::epp::epp_string & IPType);
   
   /** Returns the corresponsing epp_string text for the given epp_HostStatusType-enum
    * @param statusType The host status type as an epp_HostStatusType-enum
    * @return The host status type as an epp_string
    * @throw epp_XMLException If statusType is not a valid epp_HostStatusType
    */
   eppobject::epp::epp_string returnStatusType(const epp_HostStatusType & statusType);
   
   /** Returns the corresponsing epp_HostStatusType for the given epp_string
    * @param statusType The host status type as an epp_string
    * @return The host status type as an epp_HostStatusType-enum
    * @throw epp_XMLException If statusType is not a valid epp_HostStatusType
    */
   epp_HostStatusType returnStatusEnumType(const eppobject::epp::epp_string & statusType);
}}

#endif
