/************************************************************************
 * EPP RTK C++
 * Copyright (C) 2001, 2002 The Global Name Registry, Limited 
 * 
 * This library is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published
 * by the Free Software Foundation; either version 2.1 of the License, or
 * (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact information:  epprtk@gnr.com
 *
 *                       EPP RTK
 *                       The Global Name Registry, Limited
 *                       125 High Holborn
 *                       London WC1V 6QA
 *                       United Kingdom
 ************************************************************************/

#ifndef __EPP_ACTION_H
#define __EPP_ACTION_H

/** @file epp_Action.h
 *  @brief Definition of epp_Action and epp_Action_ref
 *  @author Asbjorn Steira Mikkelsen
 */

#include "data/epp_eppdata.h"

namespace eppobject { namespace epp {
   
   /// Abstract super-class for all EPP commands
   class epp_Action {
      
    public:
      
      /// Null constructor
      epp_Action() {};
      
      /// Destructor
      virtual ~epp_Action() {};

      /** Abstract function. It takes the request data object (if any), parses it,
       *  and returns the corresponding correctly formatted EPP xml request as an
       *  #epp_string
       * @return The request xml string
       */
      virtual eppobject::epp::epp_string toXML() = 0;
      
      /** Abstract function. It takes the response xml #epp_string, parses it,
       *  and puts elements into the class' response data object.
       * @param xml The response xml string
       */
      virtual void fromXML(const eppobject::epp::epp_string & xml) = 0;
   };
   
   /// Typedef for the ref to the epp_Action class
   typedef refcnt_ptr<epp_Action> epp_Action_ref;
   
}}

#endif
