/************************************************************************
 * EPP RTK C++
 * Copyright (C) 2001, 2002 The Global Name Registry, Limited 
 * 
 * This library is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published
 * by the Free Software Foundation; either version 2.1 of the License, or
 * (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact information:  epprtk@gnr.com
 *
 *                       EPP RTK
 *                       The Global Name Registry, Limited
 *                       125 High Holborn
 *                       London WC1V 6QA
 *                       United Kingdom
 ************************************************************************/

#ifndef __EPP_CONTACTDELETE_H
#define __EPP_CONTACTDELETE_H

/** @file epp_ContactDelete.h
 *  @brief Definition of epp_ContactDelete and epp_ContactDelete_ref
 *  @author Asbjorn Steira Mikkelsen
 */

#include "data/epp_ContactDeleteReq.h"
#include "data/epp_ContactDeleteRsp.h"
#include "epp_Action.h"

namespace eppobject { namespace contact {
   
   /// Interface class for the EPP contact <delete> command
   class epp_ContactDelete : public eppobject::epp::epp_Action {
      
    private:
      epp_ContactDeleteReq_ref m_request; /**< Request to send to the server */
      epp_ContactDeleteRsp_ref m_response; /**< Response received from server */
      
    public:
      
      /// Null constructor
      epp_ContactDelete() {};

      /// Destructor
      virtual ~epp_ContactDelete() {};

      /** Function setting the object's request element
       * @param parms Request element to use
       */
      void setRequestData(const epp_ContactDeleteReq & parms);
      
      /** Function returning the object's response element
       * @return Response element of object
       */
      epp_ContactDeleteRsp_ref getResponseData() const;
      
      /** Function that takes the request data object, parses it, and returns
       *  the corresponding correctly formatted EPP xml request as an
       *  eppobject::epp#epp_string
       * @return The request xml string
       * @throw eppobject::epp::epp_XMLException If request object is missing critical data
       */
      virtual eppobject::epp::epp_string toXML();
      
      /** Function that takes the response xml eppobject::epp#epp_string, parses it,
       *  and puts elements into the class' response data object.
       * @param xml The response xml string
       * @throw eppobject::epp::epp_XMLException If response string is missing critical data
       */
      virtual void fromXML(const eppobject::epp::epp_string & xml);
   };
   
   /// Typedef for the ref to the epp_ContactDelete class
   typedef refcnt_ptr<epp_ContactDelete> epp_ContactDelete_ref;
   
}}

#endif
