/************************************************************************
 * EPP RTK C++
 * Copyright (C) 2001, 2002 The Global Name Registry, Limited 
 * 
 * This library is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published
 * by the Free Software Foundation; either version 2.1 of the License, or
 * (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact information:  epprtk@gnr.com
 *
 *                       EPP RTK
 *                       The Global Name Registry, Limited
 *                       125 High Holborn
 *                       London WC1V 6QA
 *                       United Kingdom
 ************************************************************************/

#include "config.h"
#include "ltoa.h"
#include "epp_DomainRenew.h"
#include <domtools/dom_output.h>
#include <domtools/dom_wrapper.h>
#include "data/epp_domainXMLbase.h"
#include "data/epp_XMLException.h"


using namespace std;
using namespace domtools;
using namespace eppobject::domain;
using namespace eppobject::epp;


void epp_DomainRenew::setRequestData(const epp_DomainRenewReq & parms)
{
   m_request.ref(new epp_DomainRenewReq(parms));
}

epp_DomainRenewRsp_ref epp_DomainRenew::getResponseData() const
{
   return m_response;
}


epp_string epp_DomainRenew::toXML()
{
   if(m_request == NULL || m_request->m_cmd == NULL || m_request->m_name == NULL) {
      throw epp_XMLException(__FILE__, __LINE__, "Missing data in request");
   }
   
   EPP_output xml_request;
   xml_request.setWhitespace(Whitespace);
   
   createStandardXMLHeader(xml_request);
   
   xml_request.beginTag("command");
   
   xml_request.beginTag("renew");
   xml_request.beginTag("domain:renew");
   
   setCommandSchemaAttributes(xml_request);
   
   xml_request.putTag("domain:name",*m_request->m_name);
   
   if(m_request->m_current_expiration_date != NULL) {
      xml_request.putTag("domain:curExpDate", *m_request->m_current_expiration_date);
   } // if "m_current_expiration_date"
   
   if(m_request->m_period != NULL) {
      
      xml_request.beginTag("domain:period");
      if(m_request->m_period->m_unit != NULL) {
	 xml_request.putAttribute("unit", returnPeriodUnitType(*m_request->m_period->m_unit));
      }
      if( m_request->m_period->m_value != NULL) {
	 xml_request.putCDATA(ltoa(*m_request->m_period->m_value));
      }
      xml_request.endTag("domain:period");
   } // if "m_period"
   
   xml_request.endTag("domain:renew");   
   xml_request.endTag("renew");
   
   addExtensionElements(xml_request, m_request->m_cmd->m_extentions);
   
   if(m_request->m_cmd->m_client_trid != NULL) {
      xml_request.putTag("clTRID",*m_request->m_cmd->m_client_trid);
   } // if "m_client_trid"
   
   xml_request.endTag("command");
   
   createStandardXMLFooter(xml_request);
   
   return xml_request.getString();  
}

void epp_DomainRenew::fromXML(const eppobject::epp::epp_string & xml)
{
   dom_ptr doc = createDOMDocument(xml);
   
   dom_ptr responseNode = dom_ptr(doc->getTag("response"));
   
   if(responseNode->isNull()) {
      throw epp_XMLException(__FILE__, __LINE__, "Unable to find response-element");
   }
   
   m_response.ref(new epp_DomainRenewRsp());
   
   epp_Response_ref res = createGenericResponse(responseNode);
   m_response->m_rsp = res;
   
   dom_ptr renDataNode = dom_ptr(getresDataInfo(responseNode, "renData"));
   
   if(renDataNode->isNull()) {
      throw epp_XMLException(__FILE__, __LINE__, "Unable to find renData-element");
   }
   
   dom_ptr renChildNode = dom_ptr(renDataNode->getFirstChildElement());
   
   string elemPrefix = renDataNode->getPrefix();
   
   while (!renChildNode->isNull()) {
      string nodeName = renChildNode->getNodeName();
      
      if(nodeName == string(elemPrefix + ":name")) {
	 m_response->m_name.ref(new epp_string(renChildNode->getNodeData()));
//	 cout << "name: " << *m_response->m_name << endl;
      } // if "name"
      
      else if(nodeName == string(elemPrefix + ":exDate")) {
	 m_response->m_expiration_date.ref(new epp_datetime(renChildNode->getNodeData()));
//	 cout << "exDate: " << *m_response->m_expiration_date << endl;
      } // if "exDate"
      
      renChildNode = dom_ptr(renChildNode->getNextSiblingElement());
   } // while "renChildNode"
   
}
