/************************************************************************
 * EPP RTK C++
 * Copyright (C) 2001, 2002 The Global Name Registry, Limited 
 * 
 * This library is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published
 * by the Free Software Foundation; either version 2.1 of the License, or
 * (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact information:  epprtk@gnr.com
 *
 *                       EPP RTK
 *                       The Global Name Registry, Limited
 *                       125 High Holborn
 *                       London WC1V 6QA
 *                       United Kingdom
 ************************************************************************/

#include "config.h"
#include "epp_HostDelete.h"
#include <domtools/dom_output.h>
#include <domtools/dom_wrapper.h>
#include "data/epp_hostXMLbase.h"
#include "data/epp_XMLException.h"


using namespace std;
using namespace domtools;
using namespace eppobject::host;
using namespace eppobject::epp;


void epp_HostDelete::setRequestData(const epp_HostDeleteReq & parms)
{
   m_request.ref(new epp_HostDeleteReq(parms));
}

epp_HostDeleteRsp_ref epp_HostDelete::getResponseData() const
{
   return m_response;
}


epp_string epp_HostDelete::toXML()
{
   if(m_request == NULL || m_request->m_cmd == NULL || m_request->m_name == NULL) {
      throw epp_XMLException(__FILE__, __LINE__, "Missing data in request");
   }
   
   EPP_output xml_request;
   xml_request.setWhitespace(Whitespace);
   
   createStandardXMLHeader(xml_request);
   
   xml_request.beginTag("command");
   
   xml_request.beginTag("delete");
   xml_request.beginTag("host:delete");

   setCommandSchemaAttributes(xml_request);
   
   xml_request.putTag("host:name",*m_request->m_name);
   
   xml_request.endTag("host:delete");   
   xml_request.endTag("delete");
   
   addExtensionElements(xml_request, m_request->m_cmd->m_extentions);
   
   if(m_request->m_cmd->m_client_trid != NULL) {
      xml_request.putTag("clTRID",*m_request->m_cmd->m_client_trid);
   } // if "m_cmd->m_client_trid"
   
   xml_request.endTag("command");
   
   createStandardXMLFooter(xml_request);
   
   return xml_request.getString();  
}

void epp_HostDelete::fromXML(const eppobject::epp::epp_string & xml)
{
   dom_ptr doc = createDOMDocument(xml);
   
   dom_ptr responseNode = dom_ptr(doc->getTag("response"));
   
   if(responseNode->isNull()) {
      throw epp_XMLException(__FILE__, __LINE__, "Unable to find response-element");
   }
   
   epp_Response_ref res = createGenericResponse(responseNode);
   
   m_response.ref(new epp_HostDeleteRsp(res));
}
