/************************************************************************
 * EPP RTK C++
 * Copyright (C) 2001, 2002 The Global Name Registry, Limited 
 * 
 * This library is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published
 * by the Free Software Foundation; either version 2.1 of the License, or
 * (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact information:  epprtk@gnr.com
 *
 *                       EPP RTK
 *                       The Global Name Registry, Limited
 *                       125 High Holborn
 *                       London WC1V 6QA
 *                       United Kingdom
 ************************************************************************/

#include "config.h"
#include "epp_Poll.h"
#include <domtools/dom_output.h>
#include <domtools/dom_wrapper.h>
#include "data/epp_eppXMLbase.h"
#include "data/epp_XMLException.h"
#include "data/epp_PollResFactory.h"

using namespace std;
using namespace domtools;
using namespace eppobject::epp;
using namespace eppobject::domain;
using namespace eppobject::contact;

void epp_Poll::setRequestData(const epp_PollReq & parms)
{
   m_request.ref(new epp_PollReq(parms));
}

epp_PollRsp_ref epp_Poll::getResponseData() const
{
   return m_response;
}

epp_string epp_Poll::toXML()
{
   if(m_request == NULL || m_request->m_cmd == NULL) {
      throw epp_XMLException(__FILE__, __LINE__, "Missing data in request");
   }
   
   EPP_output xml_request;
   xml_request.setWhitespace(Whitespace);
   
   createStandardXMLHeader(xml_request);
   
   xml_request.beginTag("command");
   
   xml_request.beginTag("poll");
   initReqMap();
   
   if(m_request->m_op != NULL) {
      xml_request.putAttribute("op", pollReqTypeMap[*m_request->m_op]);
   } // if "m_op"
   
   if(m_request->m_msgID != NULL) {
      xml_request.putAttribute("msgID", *m_request->m_msgID);
   } // if "m_msgID"
   
   xml_request.endTag("poll");

   addExtensionElements(xml_request, m_request->m_cmd->m_extentions);
   
   if(m_request->m_cmd->m_client_trid != NULL) {
      xml_request.putTag("clTRID",*m_request->m_cmd->m_client_trid);
   } // if "m_cmd->m_client_trid"
   
   xml_request.endTag("command");

   createStandardXMLFooter(xml_request);
   
   return xml_request.getString();
}


void epp_Poll::fromXML(const eppobject::epp::epp_string & xml)
{  
   dom_ptr doc = createDOMDocument(xml);
   
   dom_ptr responseNode = dom_ptr(doc->getTag("response"));
   
   if(responseNode->isNull()) {
      throw epp_XMLException(__FILE__, __LINE__, "Unable to find response-element");
   }
   
   epp_Response_ref res = createGenericResponse(responseNode);
   m_response.ref(new epp_PollRsp());
   m_response->m_rsp = res;
   
   // Handle resData (if any):
   dom_ptr resDataNode = dom_ptr(doc->getTag("resData"));
   
   if(!resDataNode->isNull()) {
      dom_ptr resChildNode = dom_ptr(resDataNode->getFirstChildElement());
      
      if(!resChildNode->isNull()) {
	 
	 // Which poll resData to handle by default:
	 epp_PollResFactory::addClass("domain", "trnData", createDomainPollResData);
	 epp_PollResFactory::addClass("contact", "trnData", createContactPollResData);
	 
	 epp_PollResData * ptr = epp_PollResFactory::create(resChildNode->getPrefix(),
							    resChildNode->getLocalName());
	 
	 if(!ptr) {
	    throw epp_XMLException(__FILE__, __LINE__, "Unknown poll resData");
	 } else {
	    m_response->m_res_data = ptr->createPollResData(resChildNode);
	 }
	 
	 delete ptr;
	 
      } // if "resChildNode"
      
   } // if "resDataNode"
}
   

void epp_Poll::initReqMap()
{
   pollReqTypeMap[ACK] = "ack";
   pollReqTypeMap[REQ] = "req";
}
