/************************************************************************
 * EPP RTK C++
 * Copyright (C) 2001, 2002 The Global Name Registry, Limited 
 * 
 * This library is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published
 * by the Free Software Foundation; either version 2.1 of the License, or
 * (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact information:  epprtk@gnr.com
 *
 *                       EPP RTK
 *                       The Global Name Registry, Limited
 *                       125 High Holborn
 *                       London WC1V 6QA
 *                       United Kingdom
 ************************************************************************/

/* $Header: /cvsroot/epp-rtk/epp-rtk/c++/src/main_contactinfo.cc,v 1.19 2003/07/18 20:21:19 tubadanm Exp $ */

#include <string>
#include <vector>
#include <iostream>

#include "data/epp_ContactInfoReq.h"
#include "data/epp_ContactInfoRsp.h"
#include "data/epp_contactXMLbase.h"
#include "data/epp_XMLException.h"
#include "data/epp_Exception.h"
#include "epp_Action.h"
#include "epp_ContactInfo.h"
#include "epp_Session.h"
#include "testTools.h"

using namespace std;
using namespace eppobject::contact;
using namespace eppobject::epp;


void printRsp(const epp_ContactInfoRsp_ref & req)
{
   cout << "Printing Response:\n_______________________________\n";
   
   if(req != NULL) {
      
      printResponsePart1(req->m_rsp);
      printResDataHeaders("contact", "infData");
      
      if(req->m_id != NULL)
	cerr << "<contact:id>" << *req-> m_id << "</contact:id>" << endl;

      if(req->m_roid != NULL)
	cerr << "<contact:roid>" << *req->m_roid << "</contact:roid>" << endl;
      
      if(req->m_status != NULL)
	{
	   for(epp_contact_status_seq::iterator i = req->m_status->begin();
	       i != req->m_status->end(); i++)
	     {
		cerr << "<contact:status";
		if(i->m_type != NULL) {
		   string status = returnStatusType(*i->m_type);
		   cerr << " s=\"" << status << "\"";
		}
		if(i->m_lang != NULL)
		  cerr << " m_lang :" << *i->m_lang << endl;
		if(i->m_value != NULL)
		  cerr << " m_value: " << *i->m_value << endl;
		
		cerr << "/>" << endl;
	     }
	}

      if ( req->m_addresses != NULL ) {
         for ( epp_ContactNameAddress_seq::iterator i = req->m_addresses->begin();
               i != req->m_addresses->end();
               i++ ) {

            map<epp_ContactPostalInfoType, string> postalInfoMap;
            postalInfoMap[INT] = "int";
            postalInfoMap[LOC] = "loc";

	    cerr << "<contact:postalInfo type=\""<<postalInfoMap[*i->m_type]<<"\">" << endl;
	    if(i->m_name != NULL)
	      cerr << "\t<contact:name>" << *i->m_name << "</contact:name>" << endl;
	    if(i->m_org != NULL)
	      cerr << "\t<contact:org>" << *i->m_org << "</contact:org>" << endl;

	    if(i->m_address != NULL) {
	       cerr << "\t<contact:addr>" << endl;
	       if(i->m_address->m_street1 != NULL)
	         cerr << "\t\t<contact:street>" << *i->m_address->m_street1 << "</contact:street>" << endl;
	       if(i->m_address->m_street2 != NULL)
	         cerr << "\t\t<contact:street>" << *i->m_address->m_street2 << "</contact:street>" << endl;
	       if(i->m_address->m_street3 != NULL)
	         cerr << "\t\t<contact:street>" << *i->m_address->m_street3 << "</contact:street>" << endl;
	       if(i->m_address->m_city != NULL)
	         cerr << "\t\t<contact:city>" << *i->m_address->m_city << "</contact:city>" << endl;
	       if(i->m_address->m_state_province != NULL)
	         cerr << "\t\t<contact:sp>" << *i->m_address->m_state_province << "</contact:sp>" << endl;
	       if(i->m_address->m_postal_code != NULL)
	         cerr << "\t\t<contact:pc>" << *i->m_address->m_postal_code << "</contact:pc>" << endl;
	       if(i->m_address->m_country_code != NULL)
	         cerr << "\t\t<contact:cc>" << *i->m_address->m_country_code << "</contact:cc>" << endl;

	       cerr << "\t</contact:addr>" << endl;
	    }

	    cerr << "</contact:postalInfo>" << endl;
         }
      }
      
      if(req->m_voice != NULL) {
	 cerr << "<contact:voice";
	 if(req->m_voice->m_extension != NULL)
	   cerr << " x=\"" << *req->m_voice->m_extension << "\"";
	 cerr << ">";
	   
	 if(req->m_voice->m_value != NULL)
	   cerr << *req->m_voice->m_value;

      	 cerr << "</contact:voice>" << endl;
      }
      
      if(req->m_fax != NULL) {
	 cerr << "<contact:fax";
	 if(req->m_fax->m_extension != NULL)
	   cerr << " x=\"" << *req->m_fax->m_extension << "\"";
	 cerr << ">";
	 
	 if(req->m_fax->m_value != NULL)
	   cerr << *req->m_fax->m_value;
	 
      	 cerr << "</contact:fax>" << endl;
	 
      }
      
      if(req->m_email != NULL)
	cerr << "<contact:email>" << *req-> m_email << "</contact:email>" << endl;
      
      if(req->m_client_id != NULL)
	cerr << "<contact:clID>" << *req->m_client_id << "</contact:clID>" << endl;
      
      if(req->m_created_by != NULL)
	cerr << "<contact:crID>" << *req->m_created_by << "</contact:crID>" << endl;
      
      if(req->m_created_date != NULL)
	cerr << "<contact:crDate>" << *req->m_created_date << "</contact:crDate>" << endl;
      
      if(req->m_updated_by != NULL)
	cerr << "<contact:upID>" << *req->m_updated_by << "</contact:upID>" << endl;
      
      if(req->m_updated_date != NULL)
	cerr << "<contact:upDate>" << *req->m_updated_date << "</contact:upDate>" << endl;
      
      if(req->m_transfer_date != NULL)
	cerr << "<contact:trDate>" << *req->m_transfer_date << "</contact:trDate>" << endl;
      
      if(req->m_auth_info != NULL) {
	 cerr << "<contact:authInfo";
	 
	 if(req->m_auth_info->m_roid != NULL)
	    cerr << " roid=\"" << *req->m_auth_info->m_roid << "\"";
	 
	 cerr << ">";
	 
	 if(req->m_auth_info->m_value != NULL) {

            string type;

	    if(req->m_auth_info->m_type != NULL) {
	       switch(*req->m_auth_info->m_type) {
	        case PW: type = "pw"; break;
	        case EXT: type = "ext"; break;
	        default: type = "**UNKNOWN**";
	       }
	    }	 

	    cerr << "\n\t<contact:"<<type<<">"<<*req->m_auth_info->m_value<<"</contact:"<<type<<">\n";
         }
	 
	 cerr << "</contact:authInfo>" << endl;
	 
      }
       
      printResDataFooter("contact", "infData");
      printResponsePart2(req->m_rsp);
   }
   
   cout << "_______________________________\n";
} // printRsp

int main(int argc, char * argv[]) {
   
   epp_Session test;
   
   string username, password;
   
   string extra_usage = "[-extradata=trid=xxx:id=abc]";
   if(!handleArgs(test, argc, argv, username, password, extra_usage))
     return 1;

   map<string,string> extraDataMap;
   
   if(argc > 1) {
      for(int parm = 1; parm < argc; parm++) {
	 
	 if (!strncmp(argv[parm], "-extradata=", 11)) {
#ifdef RTK_DEBUG
            cout << "Found extra data param..." << endl;
#endif
	    string td = &argv[parm][11];
	    extraDataMap = getExtraDataMap(td);
	 }
      }
   }
   
   testLogIn(test, username, password);
   
   try {
      
      epp_ContactInfoReq_ref l_req(new epp_ContactInfoReq());

      string trID = "ABC-12345";
      if(extraDataMap.find("trid") != extraDataMap.end()) trID = extraDataMap["trid"];
      
      l_req->m_cmd.ref(new epp_Command(NULL,
				       epp_trid(trID)));
      
      if(extraDataMap.find("id") == extraDataMap.end()) {
	 l_req->m_id.ref(new epp_string("sh8013"));
      }
      else {
	 l_req->m_id.ref(new epp_string(extraDataMap["id"]));
      }
      
      epp_ContactInfo_ref l_obj(new epp_ContactInfo());
      
      l_obj->setRequestData(*l_req);
      
      test.processAction(l_obj);
      
      epp_ContactInfoRsp_ref l_rsp = l_obj->getResponseData();
      
#ifndef TEST_IO_REQUEST2CERR
      printRsp(l_rsp);
#endif      
      return 0;
      
   }
   catch(const epp_XMLException & ex) {
      cout << "Exception: " << ex.getString() << endl;
   }
   catch(const epp_Exception & ex) {
      cout << "Exception: " << endl;
#ifndef TEST_IO_REQUEST2CERR
      cerr << "<response>" << endl;
      printResultsSeq(ex.m_details);
      printTransID(ex.m_trans_id);
      cerr << "</response>" << endl;
#endif
   }
   catch(const epptransport::epp_TrException & ex) {
      cout << "Exception: " << ex.getString() << endl;
   }
   catch(...) {
      cout << "Something else went wrong...\n";
   }
   
}
