/************************************************************************
 * EPP RTK C++
 * Copyright (C) 2001, 2002 The Global Name Registry, Limited 
 * 
 * This library is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published
 * by the Free Software Foundation; either version 2.1 of the License, or
 * (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact information:  epprtk@gnr.com
 *
 *                       EPP RTK
 *                       The Global Name Registry, Limited
 *                       125 High Holborn
 *                       London WC1V 6QA
 *                       United Kingdom
 ************************************************************************/

/* $Header: /cvsroot/epp-rtk/epp-rtk/c++/src/main_contacttransfer.cc,v 1.17 2003/07/18 20:21:19 tubadanm Exp $ */

#include <string>
#include <iostream>

#include "data/epp_ContactTransferReq.h"
#include "data/epp_ContactTransferRsp.h"
#include "data/epp_XMLException.h"
#include "data/epp_Exception.h"
#include "epp_Action.h"
#include "epp_ContactTransfer.h"
#include "epp_Session.h"
#include "testTools.h"
#include "data/epp_eppXMLbase.h"

using namespace std;
using namespace eppobject::contact;
using namespace eppobject::epp;


void printRsp(const epp_ContactTransferRsp_ref & req)
{
   cout << "Printing Response:\n_______________________________\n";
   
   if(req != NULL) {
      
      printResponsePart1(req->m_rsp);
      printResDataHeaders("contact", "trnData");

      if(req->m_trn_data != NULL) {
	 if(req->m_trn_data->m_id != NULL)
	   cerr << "<contact:id>" << *req->m_trn_data->m_id << "</contact:id>" << endl;
	 
	 if(req->m_trn_data->m_transfer_status != NULL) {
	    string trStatus = returnTransferStatusType(*req->m_trn_data->m_transfer_status);
	    cerr << "<contact:trStatus>" << trStatus << "</contact:trStatus>" << endl;
	 }	
	 
	 if(req->m_trn_data->m_request_client_id != NULL)
	   cerr << "<contact:reID>" << *req->m_trn_data->m_request_client_id << "</contact:reID>" << endl;
	 
	 if(req->m_trn_data->m_request_date != NULL)
	   cerr << "<contact:reDate>" << *req->m_trn_data->m_request_date << "</contact:reDate>" << endl;
	 
	 if(req->m_trn_data->m_action_client_id != NULL)
	   cerr << "<contact:acID>" << *req->m_trn_data->m_action_client_id << "</contact:acID>" << endl;
	 
	 if(req->m_trn_data->m_action_date != NULL)
	   cerr << "<contact:acDate>" << *req->m_trn_data->m_action_date << "</contact:acDate>" << endl;
      }
      
      printResDataFooter("contact", "trnData");
      printResponsePart2(req->m_rsp);
   }
   
   
   cout << "_______________________________\n";
} // printRsp

int main(int argc, char * argv[]) {
   
   epp_Session test;
   
   string username, password;
   
   string extra_usage = "[-extradata=trid=xxx:id=abc:op=(query|request|cancel|approve|reject):authinfo:pw/xyz]";
   if(!handleArgs(test, argc, argv, username, password, extra_usage))
     return 1;
   
   map<string,string> extraDataMap;
   
   if(argc > 1) {
      for(int parm = 1; parm < argc; parm++) {
	 
	 if (!strncmp(argv[parm], "-extradata=", 11)) {
#ifdef RTK_DEBUG
            cout << "Found extra data param..." << endl;
#endif
	    string td = &argv[parm][11];
	    extraDataMap = getExtraDataMap(td);
	 }
      }
   }
   
   testLogIn(test, username, password);
   
   try {
      
      epp_ContactTransferReq_ref l_req(new epp_ContactTransferReq());
      
      string trID = "ABC-12345";
      if(extraDataMap.find("trid") != extraDataMap.end()) trID = extraDataMap["trid"];
      
      l_req->m_cmd.ref(new epp_Command(NULL,
				       epp_trid(trID)));
      
      epp_ContactTransfer_ref l_obj(new epp_ContactTransfer());
      epp_ContactTransferRsp_ref l_rsp;

      l_req->m_trans.ref(new epp_TransferRequest());

      if ( extraDataMap.find("id") == extraDataMap.end() ) {
         l_req->m_id.ref(new epp_string("sh8013"));
      } else if ( ! extraDataMap["id"].empty() ) {
         l_req->m_id.ref(new epp_string(extraDataMap["id"]));
      }

      if ( extraDataMap.find("op") == extraDataMap.end() ) {
	 l_req->m_trans->m_op.ref(new epp_TransferOpType(QUERY));
      } else if ( ! extraDataMap["op"].empty() ) {
	 l_req->m_trans->m_op.ref(new epp_TransferOpType(returnTransferType(extraDataMap["op"])));
      }

      if ( extraDataMap.find("authinfo") == extraDataMap.end() ) {
	 l_req->m_trans->m_auth_info.ref(new epp_AuthInfo());
	 l_req->m_trans->m_auth_info->m_type.ref(new epp_AuthInfoType(PW));
	 l_req->m_trans->m_auth_info->m_value.ref(new epp_string("2fooBAR"));
      } else if ( ! extraDataMap["authinfo"].empty() ) {
         string authinfo = extraDataMap["authinfo"];
         string type, value;
         unsigned int sep = authinfo.find("/");
         if ( sep != string::npos ) {
            type = authinfo.substr(0,sep);
            value = authinfo.substr(sep+1);
	    l_req->m_trans->m_auth_info.ref(new epp_AuthInfo());
            if ( type == "pw" )  l_req->m_trans->m_auth_info->m_type.ref(new epp_AuthInfoType(PW));
            if ( type == "ext" ) l_req->m_trans->m_auth_info->m_type.ref(new epp_AuthInfoType(EXT));
	    l_req->m_trans->m_auth_info->m_value.ref(new epp_string(value));
         }
      }

      l_obj->setRequestData(*l_req);
      
      test.processAction(l_obj);
      
      l_rsp = l_obj->getResponseData();
      
#ifndef TEST_IO_REQUEST2CERR
      printRsp(l_rsp);
#endif      
      return 0;
      
   }
   catch(const epp_XMLException & ex) {
      cout << "Exception: " << ex.getString() << endl;
   }
   catch(const epp_Exception & ex) {
      cout << "Exception: " << endl;
#ifndef TEST_IO_REQUEST2CERR
      cerr << "<response>" << endl;
      printResultsSeq(ex.m_details);
      printTransID(ex.m_trans_id);
      cerr << "</response>" << endl;
#endif
   }
   catch(const epptransport::epp_TrException & ex) {
      cout << "Exception: " << ex.getString() << endl;
   }
   catch(...) {
      cout << "Something else went wrong...\n";
   }
   
}
