/************************************************************************
 * EPP RTK C++
 * Copyright (C) 2001, 2002 The Global Name Registry, Limited 
 * 
 * This library is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published
 * by the Free Software Foundation; either version 2.1 of the License, or
 * (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact information:  epprtk@gnr.com
 *
 *                       EPP RTK
 *                       The Global Name Registry, Limited
 *                       125 High Holborn
 *                       London WC1V 6QA
 *                       United Kingdom
 ************************************************************************/

/* $Header: /cvsroot/epp-rtk/epp-rtk/c++/src/main_domaincreate.cc,v 1.15 2003/07/18 20:21:19 tubadanm Exp $ */

#include <vector>
#include <iostream>

#include "data/epp_DomainCreateReq.h"
#include "data/epp_DomainCreateRsp.h"
#include "data/epp_XMLException.h"
#include "data/epp_Exception.h"
#include "epp_Action.h"
#include "epp_DomainCreate.h"
#include "epp_Session.h"
#include "testTools.h"

using namespace std;
using namespace eppobject::domain;
using namespace eppobject::epp;

void printRsp(const epp_DomainCreateRsp_ref & req)
{
   cout << "Printing Response:\n_______________________________\n";
   
   if(req != NULL) {
      
      printResponsePart1(req->m_rsp);
      printResDataHeaders("domain", "creData");
      
      if(req->m_name != NULL)
	cerr << "<domain:name>" << *req-> m_name << "</domain:name>" << endl;
      
      if(req->m_creation_date != NULL)
	cerr << "<domain:crDate>" << *req-> m_creation_date << "</domain:crDate>" << endl;
      
      if(req->m_expiration_date != NULL)
	cerr << "<domain:exDate>" << *req-> m_expiration_date << "</domain:exDate>" << endl;
      
      printResDataFooter("domain", "creData");
      printResponsePart2(req->m_rsp);
   }
   
   
   cout << "_______________________________\n";
} // printRsp


int main(int argc, char * argv[]) {
   
   epp_Session test;
   
   string username, password;
   
   string extra_usage = "[-extradata=trid=xxx:domain=abc.tld:period=1:ns1=asdf:ns2=asdf{:...}:reg=abc:contact1=t/abc{:...}:authinfo=pw/38239]";
   if(!handleArgs(test, argc, argv, username, password, extra_usage))
     return 1;
   
   map<string,string> extraDataMap;
   
   if(argc > 1) {
      for(int parm = 1; parm < argc; parm++) {
	 
	 if (!strncmp(argv[parm], "-extradata=", 11)) {
#ifdef RTK_DEBUG
            cout << "Found extra data param..." << endl;
#endif
	    string td = &argv[parm][11];
	    extraDataMap = getExtraDataMap(td);
	 }
      }
   }
   
   testLogIn(test, username, password);
   
   try {
       
      epp_DomainCreateReq_ref l_req(new epp_DomainCreateReq());
   
      string trID = "ABC-12345";
      if(extraDataMap.find("trid") != extraDataMap.end()) trID = extraDataMap["trid"];
      
      l_req->m_cmd.ref(new epp_Command(NULL,
				       NULL,
				       epp_trid(trID)));
      
      if ( extraDataMap.find("domain") == extraDataMap.end() ) l_req->m_name.ref(new epp_string("example.com"));
      else l_req->m_name.ref(new epp_string(extraDataMap["domain"]));
      if ( extraDataMap.find("period") == extraDataMap.end() ) l_req->m_period.ref(new epp_DomainPeriod(YEAR, 2));
      else if ( ! extraDataMap["period"].empty() ) l_req->m_period.ref(new epp_DomainPeriod(YEAR,atoi(extraDataMap["period"].c_str())));

      l_req->m_name_servers.ref(new epp_string_seq());
      if ( extraDataMap.find("ns1") == extraDataMap.end() ) {
         l_req->m_name_servers->push_back("ns1.example.com");
         l_req->m_name_servers->push_back("ns2.example.com");
      } else {
         char key[5];
	 for(unsigned int n = 1; n <= 14; n++) {
            sprintf(key,"ns%d",n);
            if ( extraDataMap.find(key) == extraDataMap.end() ) break;
            if ( extraDataMap[key] == "-1" ) break;
	    l_req->m_name_servers->push_back(extraDataMap[key]);
	 }
      }
      if ( extraDataMap.find("reg") == extraDataMap.end() ) l_req->m_registrant.ref(new epp_string("jd1234"));
      else l_req->m_registrant.ref(new epp_string(extraDataMap["reg"]));
      
      l_req->m_contacts.ref(new epp_domain_contact_seq());
      if ( extraDataMap.find("contact1") == extraDataMap.end() ) {
         epp_DomainContact Cont1(ADMIN, epp_string("sh8013"));
	 l_req->m_contacts->push_back(Cont1);
	 epp_DomainContact Cont2(TECH,  epp_string("sh8013"));
	 l_req->m_contacts->push_back(Cont2);
      } else {
         char key[10]; // contactxx
	 for(unsigned int n = 1; n <= 10; n++) {
            sprintf(key,"contact%d",n);
            if ( extraDataMap.find(key) == extraDataMap.end() ) break;
	    epp_DomainContact contact;
            string type, value;
            if ( ! extraDataMap[key].empty() ) {
               // contact1=t/abc
               // contact2=a/qwerty
               // etc...
               type = extraDataMap[key].substr(0,1);
               value = extraDataMap[key].substr(2);
               if ( type == "t" ) contact.m_type.ref(new epp_DomainContactType(TECH));
               if ( type == "a" ) contact.m_type.ref(new epp_DomainContactType(ADMIN));
               if ( type == "b" ) contact.m_type.ref(new epp_DomainContactType(BILLING));
               contact.m_id.ref(new epp_string(value));
	       l_req->m_contacts->push_back(contact);
            }
	 }
      }
      
      if ( extraDataMap.find("authinfo") == extraDataMap.end() ) { 
	 l_req->m_auth_info.ref(new epp_AuthInfo());
	 l_req->m_auth_info->m_type.ref(new epp_AuthInfoType(PW));
	 l_req->m_auth_info->m_value.ref(new epp_string("2fooBAR"));
      } else {
         string authinfo = extraDataMap["authinfo"];
         string type, value;
         unsigned int sep = authinfo.find("/");
         if ( sep != string::npos ) {
            type = authinfo.substr(0,sep);
            value = authinfo.substr(sep+1);
	    l_req->m_auth_info.ref(new epp_AuthInfo());
            if ( type == "pw" )  l_req->m_auth_info->m_type.ref(new epp_AuthInfoType(PW));
            if ( type == "ext" ) l_req->m_auth_info->m_type.ref(new epp_AuthInfoType(EXT));
	    l_req->m_auth_info->m_value.ref(new epp_string(value));
         }
      }
      
      epp_DomainCreate_ref l_obj(new epp_DomainCreate());
      
      l_obj->setRequestData(*l_req);
      
      test.processAction(l_obj);
      
      epp_DomainCreateRsp_ref l_rsp = l_obj->getResponseData();
      
#ifndef TEST_IO_REQUEST2CERR
      printRsp(l_rsp);
#endif
      return 0;
      
   }
   catch(const epp_XMLException & ex) {
      cout << "Exception: " << ex.getString() << endl;
   }
   catch(const epp_Exception & ex) {
      cout << "Exception: " << endl;
#ifndef TEST_IO_REQUEST2CERR
      cerr << "<response>" << endl;
      printResultsSeq(ex.m_details);
      printTransID(ex.m_trans_id);
      cerr << "</response>" << endl;
#endif
   }
   catch(const epptransport::epp_TrException & ex) {
      cout << "Exception: " << ex.getString() << endl;
   }
   catch(...) {
      cout << "Something else went wrong...\n";
   }
   
}
