/************************************************************************
 * EPP RTK C++
 * Copyright (C) 2001, 2002 The Global Name Registry, Limited 
 * 
 * This library is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published
 * by the Free Software Foundation; either version 2.1 of the License, or
 * (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact information:  epprtk@gnr.com
 *
 *                       EPP RTK
 *                       The Global Name Registry, Limited
 *                       125 High Holborn
 *                       London WC1V 6QA
 *                       United Kingdom
 ************************************************************************/

/* $Header: /cvsroot/epp-rtk/epp-rtk/c++/src/main_hostcheck.cc,v 1.14 2003/07/18 20:21:19 tubadanm Exp $ */

#include <vector>
#include <iostream>

#include "data/epp_HostCheckReq.h"
#include "data/epp_HostCheckRsp.h"
#include "data/epp_XMLException.h"
#include "data/epp_Exception.h"
#include "epp_Action.h"
#include "epp_HostCheck.h"
#include "epp_Session.h"
#include "testTools.h"

using namespace std;
using namespace eppobject::host;
using namespace eppobject::epp;


void printRsp(const epp_HostCheckRsp_ref & req)
{
   cout << "Printing Response:\n_______________________________\n";
   
   if(req != NULL) {
      printResponsePart1(req->m_rsp);
      printResDataHeaders("host", "chkData");
      
      if(req->m_results != NULL) {
	 for(epp_check_result_seq::iterator i =req->m_results->begin(); i != req->m_results->end(); i++)
	   {
	      cerr << "<host:cd>" << endl;
	      cerr << "<host:name";
	      if(i->m_avail != NULL) {
		 string avail = *i->m_avail ? "1" : "0";
                 cerr << " avail=\"" << avail << "\"";
              }
	      cerr << ">";
	      
	      if(i->m_value != NULL)
		cerr << *i->m_value;
	      
	      cerr << "</host:name>" << endl;
	      
	      if(i->m_reason != NULL)
		cerr << "<host:reason>" << *i->m_reason << "</host:reason>" << endl;
	      if(i->m_lang != NULL)
		cerr << "<lang>" << *i->m_lang << "</lang>" << endl;
	      
	      cerr << "</host:cd>" << endl;
	   }
      }
      
      printResDataFooter("host", "chkData");
      printResponsePart2(req->m_rsp);
   }
   
   cout << "_______________________________\n";
} // printRsp


int main(int argc, char * argv[]) {
   
   epp_Session test;
   
   string username, password;
   
   string extra_usage = "[-extradata=trid=xxx:host1=abc:host2=def:...]";
   if(!handleArgs(test, argc, argv, username, password, extra_usage))
     return 1;

   map<string,string> extraDataMap;
   
   if(argc > 1) {
      for(int parm = 1; parm < argc; parm++) {
	 
	 if (!strncmp(argv[parm], "-extradata=", 11)) {
#ifdef RTK_DEBUG
            cout << "Found extra data param..." << endl;
#endif
	    string td = &argv[parm][11];
	    extraDataMap = getExtraDataMap(td);
	 }
      }
   }
   
   testLogIn(test, username, password);
   
   try {
      
      epp_HostCheckReq_ref l_req(new epp_HostCheckReq());
      
      string trID = "ABC-12345";
      if(extraDataMap.find("trid") != extraDataMap.end()) trID = extraDataMap["trid"];
      
      l_req->m_cmd.ref(new epp_Command(NULL,
				       NULL,
				       epp_trid(trID)));
      
      epp_string_seq_ref names(new epp_string_seq());
      
      if(extraDataMap.find("host1") == extraDataMap.end()) {
	 names->push_back("ns1.example.com");
	 names->push_back("ns2.example.com");
	 names->push_back("ns3.example.com");
      }
      else {
         char key[7];
	 for(unsigned int n = 1; n <= 30; n++) {
            sprintf(key,"host%d",n);
            if ( extraDataMap[key].empty() ) break;
	    names->push_back(extraDataMap[key]);
	 }
      }
      
      l_req->m_names = names;
      
      epp_HostCheck_ref l_obj(new epp_HostCheck());
      
      l_obj->setRequestData(*l_req);
      
      test.processAction(l_obj);
      
      epp_HostCheckRsp_ref l_rsp = l_obj->getResponseData();
      
#ifndef TEST_IO_REQUEST2CERR
      printRsp(l_rsp);
#endif
      return 0;

   }
   catch(const epp_XMLException & ex) {
      cout << "Exception: " << ex.getString() << endl;
   }
   catch(const epp_Exception & ex) {
      cout << "Exception: " << endl;
#ifndef TEST_IO_REQUEST2CERR
      cerr << "<response>" << endl;
      printResultsSeq(ex.m_details);
      printTransID(ex.m_trans_id);
      cerr << "</response>" << endl;
#endif
   }
   catch(const epptransport::epp_TrException & ex) {
      cout << "Exception: " << ex.getString() << endl;
   }
   catch(...) {
      cout << "Something else went wrong...\n";
   }
   
}
