/************************************************************************
 * EPP RTK C++
 * Copyright (C) 2001, 2002 The Global Name Registry, Limited 
 * 
 * This library is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published
 * by the Free Software Foundation; either version 2.1 of the License, or
 * (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact information:  epprtk@gnr.com
 *
 *                       EPP RTK
 *                       The Global Name Registry, Limited
 *                       125 High Holborn
 *                       London WC1V 6QA
 *                       United Kingdom
 ************************************************************************/

/* $Header: /cvsroot/epp-rtk/epp-rtk/c++/src/main_hostupdate.cc,v 1.17 2003/07/18 20:21:19 tubadanm Exp $ */

#include <vector>
#include <iostream>

#include "data/epp_HostUpdateReq.h"
#include "data/epp_HostUpdateRsp.h"
#include "data/epp_XMLException.h"
#include "data/epp_Exception.h"
#include "data/epp_hostXMLbase.h"
#include "epp_Action.h"
#include "epp_HostUpdate.h"
#include "epp_Session.h"
#include "testTools.h"

using namespace std;
using namespace eppobject::host;
using namespace eppobject::epp;


void printRsp(const epp_HostUpdateRsp_ref & req)
{
   cout << "Printing Response:\n_______________________________\n";
   
   if(req != NULL)
     printResponsePart(req->m_rsp);
   
   cout << "_______________________________\n";
} // printRsp


int main(int argc, char * argv[]) {
   
   epp_Session test;
   
   string username, password;
   
   vector<string> extra_usage;
   extra_usage.push_back("[-extradata=trid=xxx:host=ns1.host.tld");
   extra_usage.push_back(" -add=status1=aaa/reason{~...}~ip1=v4/1.2.3.4~ip2=v6/1080:0:0:0:8:800:200C:417A{~...}");
   extra_usage.push_back(" -remove=status1=ccc/reason{~...}~ip1=v4/1.2.3.4~ip2=v6/1080:0:0:0:8:800:200C:417A{~...}");
   extra_usage.push_back(" -change=host=new.host.tld]");
   extra_usage.push_back("Note the use of '~' to separate keys and value, unlike the ':' from other examples");
   extra_usage.push_back("If you include spaces in the status reason, you need to quote the entire 'add' or 'remove' param");
   if(!handleArgs(test, argc, argv, username, password, extra_usage))
     return 1;
   
   map<string,string> extraDataMap;
   map<string,string> addDataMap;
   map<string,string> changeDataMap;
   map<string,string> removeDataMap;
   
   if(argc > 1) {
      for(int parm = 1; parm < argc; parm++) {
	 
	 if (!strncmp(argv[parm], "-extradata=", 11)) {
#ifdef RTK_DEBUG
            cout << "Found extra data param..." << endl;
#endif
	    string td = &argv[parm][11];
	    extraDataMap = getExtraDataMap(td);
	 }

	 if (!strncmp(argv[parm], "-add=", 5)) {
#ifdef RTK_DEBUG
            cout << "Found 'add' data param..." << endl;
#endif
	    string td = &argv[parm][5];
	    addDataMap = getExtraDataMap(td);
            if ( addDataMap.empty() ) addDataMap[""] = "dummy";
	 }

	 if (!strncmp(argv[parm], "-change=", 8)) {
#ifdef RTK_DEBUG
            cout << "Found 'change' data param..." << endl;
#endif
	    string td = &argv[parm][8];
	    changeDataMap = getExtraDataMap(td);
            if ( changeDataMap.empty() ) changeDataMap[""] = "dummy";
	 }

	 if (!strncmp(argv[parm], "-remove=", 8)) {
#ifdef RTK_DEBUG
            cout << "Found 'remove' data param..." << endl;
#endif
	    string td = &argv[parm][8];
	    removeDataMap = getExtraDataMap(td);
            if ( removeDataMap.empty() ) removeDataMap[""] = "dummy";
	 }
      }
   }
   
   testLogIn(test, username, password);
   
   try {
      
      epp_HostUpdateReq_ref l_req(new epp_HostUpdateReq());
   
      string trID = "ABC-12345";
      if(extraDataMap.find("trid") != extraDataMap.end()) trID = extraDataMap["trid"];
      
      l_req->m_cmd.ref(new epp_Command(NULL,
				       NULL,
				       epp_trid(trID)));
      

      if ( extraDataMap.find("host") == extraDataMap.end() ) l_req->m_name.ref(new epp_string("ns1.example.com"));
      else l_req->m_name.ref(new epp_string(extraDataMap["host"]));

      if( addDataMap.empty() &&
          removeDataMap.empty() &&
          changeDataMap.empty() ) {

	 // Data to add:
	 epp_HostAddress host1(IPV4, epp_string("192.1.2.3"));
	 
	 epp_host_address_seq_ref hosts1(new epp_host_address_seq);
	 hosts1->push_back(host1);
	 
	 epp_HostStatus singlestatus;
	 singlestatus.m_type.ref(new epp_HostStatusType(CLIENT_UPDATE_PROHIBITED));
	 
	 epp_host_status_seq_ref hosts1status(new epp_host_status_seq);
	 hosts1status->push_back(singlestatus);
	 
	 epp_HostUpdateAddRemove_ref toadd(new epp_HostUpdateAddRemove());
	 
	 toadd->m_addresses = hosts1;
	 toadd->m_status = hosts1status;
	 
	 // Data to rem:
	 epp_HostAddress host2(IPV6, epp_string("1080:0:0:0:8:800:200C:417A"));
	 
	 epp_host_address_seq_ref hosts2(new epp_host_address_seq());
	 hosts2->push_back(host2);
	 
	 epp_HostUpdateAddRemove_ref torem(new epp_HostUpdateAddRemove());
	 torem->m_addresses = hosts2;
	 
	 l_req->m_add = toadd;
	 l_req->m_remove = torem;
	 l_req->m_change.ref(new epp_HostUpdateChange());
	 l_req->m_change->m_name.ref(new epp_string("ns2.example.com"));

      } else {


	 if( ! addDataMap.empty() ) {
	    l_req->m_add.ref(new epp_HostUpdateAddRemove());
	    
	    if( ! addDataMap["status1"].empty() ) {
	       char status_name[10];
               int status_number = 1;
               sprintf(status_name, "status%d", status_number);

	       l_req->m_add->m_status.ref(new epp_host_status_seq());
	       
	       while( ! addDataMap[status_name].empty() ) {
		  string tmp = addDataMap[status_name];
		  
		  epp_HostStatus status;
                  string type, value;
                  unsigned int sep = tmp.find("/");
                  if ( sep != string::npos ) {
                     type  = tmp.substr(0,sep);
                     value = tmp.substr(sep+1);
                     cout << "type ["<<type<<"] value ["<<value<<"]\n";
		     status.m_type.ref(new epp_HostStatusType(returnStatusEnumType(type)));
	             status.m_value.ref(new epp_string(value));
                  } else {
		     status.m_type.ref(new epp_HostStatusType(returnStatusEnumType(tmp)));
                  }
		  l_req->m_add->m_status->push_back(status);

                  status_number++;
                  sprintf(status_name, "status%d", status_number);
	       }
	    }

	    if( ! addDataMap["ip1"].empty() ) {

	       char ip_name[5];
               int ip_number = 1;
               sprintf(ip_name, "ip%d", ip_number);

	       l_req->m_add->m_addresses.ref(new epp_host_address_seq());
	       
	       while( ! addDataMap[ip_name].empty() ) {
                  string ipstring = addDataMap[ip_name];
                  
	          unsigned int sep = ipstring.find("/");
	          if(sep != string::npos) {
	             string iptype = ipstring.substr(0,sep);
	             string ip = ipstring.substr(sep+1);
	             epp_HostAddress host(returnIPTypeEnum(epp_string(iptype)), epp_string(ip));
		     l_req->m_add->m_addresses->push_back(host);
                  }
                  ip_number++;
                  sprintf(ip_name, "ip%d", ip_number);
	       }

	    }

	 }

	 

	 if( ! removeDataMap.empty() ) {
	    l_req->m_remove.ref(new epp_HostUpdateAddRemove());
	    
	    if( ! removeDataMap["status1"].empty() ) {
	       char status_name[10];
               int status_number = 1;
               sprintf(status_name, "status%d", status_number);

	       l_req->m_remove->m_status.ref(new epp_host_status_seq());
	       
	       while( ! removeDataMap[status_name].empty() ) {
		  string tmp = removeDataMap[status_name];
		  
		  epp_HostStatus status;
                  string type, value;
                  unsigned int sep = tmp.find("/");
                  if ( sep != string::npos ) {
                     type  = tmp.substr(0,sep);
                     value = tmp.substr(sep+1);
                     cout << "type ["<<type<<"] value ["<<value<<"]\n";
		     status.m_type.ref(new epp_HostStatusType(returnStatusEnumType(type)));
	             status.m_value.ref(new epp_string(value));
                  } else {
		     status.m_type.ref(new epp_HostStatusType(returnStatusEnumType(tmp)));
                  }
		  l_req->m_remove->m_status->push_back(status);

                  status_number++;
                  sprintf(status_name, "status%d", status_number);
	       }
	    }

	    if( ! removeDataMap["ip1"].empty() ) {

	       char ip_name[5];
               int ip_number = 1;
               sprintf(ip_name, "ip%d", ip_number);

	       l_req->m_remove->m_addresses.ref(new epp_host_address_seq());
	       
	       while( ! removeDataMap[ip_name].empty() ) {
                  string ipstring = removeDataMap[ip_name];
                  
	          unsigned int sep = ipstring.find("/");
	          if(sep != string::npos) {
	             string iptype = ipstring.substr(0,sep);
	             string ip = ipstring.substr(sep+1);
	             epp_HostAddress host(returnIPTypeEnum(epp_string(iptype)), epp_string(ip));
		     l_req->m_remove->m_addresses->push_back(host);
                  }
                  ip_number++;
                  sprintf(ip_name, "ip%d", ip_number);
	       }

	    }

	 }

	 if( ! changeDataMap.empty() ) {

	    l_req->m_change.ref(new epp_HostUpdateChange());

	    if(changeDataMap.find("host") != changeDataMap.end()) {	    
	       l_req->m_change->m_name.ref(new epp_string(changeDataMap["host"]));
	    }

	 }

      }
      
      epp_HostUpdate_ref l_obj(new epp_HostUpdate());
      
      l_obj->setRequestData(*l_req);
      
      test.processAction(l_obj);
      
      epp_HostUpdateRsp_ref l_rsp = l_obj->getResponseData();
      
#ifndef TEST_IO_REQUEST2CERR
      printRsp(l_rsp);
#endif
      return 0;
      
   }
   catch(const epp_XMLException & ex) {
      cout << "Exception: " << ex.getString() << endl;
   }
   catch(const epp_Exception & ex) {
      cout << "Exception: " << endl;
#ifndef TEST_IO_REQUEST2CERR
      cerr << "<response>" << endl;
      printResultsSeq(ex.m_details);
      printTransID(ex.m_trans_id);
      cerr << "</response>" << endl;
#endif
   }
   catch(const epptransport::epp_TrException & ex) {
      cout << "Exception: " << ex.getString() << endl;
   }
   catch(...) {
      cout << "Something else went wrong...\n";
   }
   
}
