/************************************************************************
 * EPP RTK C++
 * Copyright (C) 2001, 2002 The Global Name Registry, Limited 
 * 
 * This library is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published
 * by the Free Software Foundation; either version 2.1 of the License, or
 * (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact information:  epprtk@gnr.com
 *
 *                       EPP RTK
 *                       The Global Name Registry, Limited
 *                       125 High Holborn
 *                       London WC1V 6QA
 *                       United Kingdom
 ************************************************************************/

/* $Header: /cvsroot/epp-rtk/epp-rtk/c++/src/main_logout.cc,v 1.12 2003/07/18 20:21:19 tubadanm Exp $ */

#include <string>
#include <iostream>

#include "data/epp_LogoutReq.h"
#include "data/epp_LogoutRsp.h"
#include "data/epp_XMLException.h"
#include "data/epp_Exception.h"
#include "epp_Action.h"
#include "epp_Logout.h"
#include "epp_Session.h"
#include "testTools.h"

using namespace std;
using namespace eppobject::epp;

void printRsp(const epp_LogoutRsp_ref & req)
{
   cout << "Printing Response:\n_______________________________\n";
   
   if(req != NULL)
     printResponsePart(req->m_rsp);
   
   cout << "_______________________________\n";
} // printRsp


int main(int argc, char * argv[]) {   
   
   epp_Session test;
   
   string username, password;
   
   string extra_usage = "[-extradata=trid=xxx]";
   if(!handleArgs(test, argc, argv, username, password, extra_usage))
     return 1;
   
   map<string,string> extraDataMap;
   
   if(argc > 1) {
      for(int parm = 1; parm < argc; parm++) {
	 
	 if (!strncmp(argv[parm], "-extradata=", 11)) {
            cout << "Found extra data param..." << endl;
	    string td = &argv[parm][11];
	    extraDataMap = getExtraDataMap(td);
	 }
      }
   }
   
   testLogIn(test, username, password);
   
   try {
      
      epp_LogoutReq_ref l_req(new epp_LogoutReq());
   
      string trID;
      if(extraDataMap.find("trid") == extraDataMap.end()) trID = "ABC-12345";
      else trID = extraDataMap["trid"];
      
      l_req->m_client_trid.ref(new epp_trid(trID));
      
      epp_Logout_ref l_obj(new epp_Logout());
      
      l_obj->setRequestData(*l_req);
      
      test.processAction(l_obj);
      
      epp_LogoutRsp_ref l_rsp = l_obj->getResponseData();
      
#ifndef TEST_IO_REQUEST2CERR
	printRsp(l_rsp);
#endif    
      return 0;
      
   }
   catch(const epp_XMLException & ex) {
      cout << "Exception: " << ex.getString() << endl;
   }
   catch(const epp_Exception & ex) {
      cout << "Exception: " << endl;
#ifndef TEST_IO_REQUEST2CERR
      cerr << "<response>" << endl;
      printResultsSeq(ex.m_details);
      printTransID(ex.m_trans_id);
      cerr << "</response>" << endl;
#endif
   }
   catch(const epptransport::epp_TrException & ex) {
      cout << "Exception: " << ex.getString() << endl;
   }
   catch(...) {
      cout << "Something else went wrong...\n";
   }
}
