/************************************************************************
 * EPP RTK C++
 * Copyright (C) 2001, 2002 The Global Name Registry, Limited 
 * 
 * This library is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published
 * by the Free Software Foundation; either version 2.1 of the License, or
 * (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact information:  epprtk@gnr.com
 *
 *                       EPP RTK
 *                       The Global Name Registry, Limited
 *                       125 High Holborn
 *                       London WC1V 6QA
 *                       United Kingdom
 ************************************************************************/

#ifndef __EPP_TESTTOOLS_H
#define __EPP_TESTTOOLS_H


/* $Header: /cvsroot/epp-rtk/epp-rtk/c++/src/testTools.h,v 1.18 2003/07/18 20:21:19 tubadanm Exp $ */

/** @file testTools.h
 *  @brief Definition of helper functions used for testing toolkit
 *  @author Asbjorn Steira Mikkelsen
 */

#include <string>
#include <map>
#include <iostream>

#include "data/epp_Response.h"
#include "epp_Session.h"


/** Function that takes an eppobject::epp::epp_Result sequence and writes each
 *  of them to cerr on the same format as in the originally returned xml
 *  string
 * @param results The results element returned from the server
 */
void printResultsSeq(const eppobject::epp::epp_result_seq_ref & results);

/** Function that takes an eppobject::epp::epp_TransID object and writes
 *  it to cerr on the same format as in the originally returned xml
 *  string
 * @param transID The transaction ID element returned from the server
 */
void printTransID(const eppobject::epp::epp_TransID_ref & transID);

/** Function that takes an eppobject::epp::epp_Response object and writes
 *  it to cerr on the same format as in the originally returned xml
 *  string
 * @param response The response element returned from the server
 */
void printResponsePart(const eppobject::epp::epp_Response_ref & response);

/** Function that takes an eppobject::epp::epp_Response object and writes
 *  everything up to a potential resData element to cerr on the same format
 *  as in the originally returned xml string
 * @param response The response element returned from the server
 */
void printResponsePart1(const eppobject::epp::epp_Response_ref & response);

/** Function that takes an eppobject::epp::epp_Response object and writes
 *  everything after a potential resData element to cerr on the same format
 *  as in the originally returned xml string
 * @param response The response element returned from the server
 */
void printResponsePart2(const eppobject::epp::epp_Response_ref & response);

/** Function that writes to cerr a standard resData header
 * @param object The object type (e.g., "domain")
 * @param returnType The return type (e.g., "creData")
 */
void printResDataHeaders(const std::string & object, const std::string & returntype);

/** Function that writes to cerr a standard resData footer
 * @param object The object type (e.g., "domain")
 * @param returnType The return type (e.g., "creData")
 */
void printResDataFooter(const std::string & object, const std::string & returntype);

/** Function that handles the command line arguments sent to the program
 *  and initializes the transport accordingly
 * @param sess Session to use when communicating with server
 * @param argc Count of command line arguments
 * @param argv Actual command line arguments
 * @param username Login name on server
 * @param password Password on server
 * @param extra_usage Extra usage parameters
 * @return true if arguments set correcetly, otherwise false
 */
bool handleArgs(eppobject::epp::epp_Session & sess, 
		int argc, char * argv[],
		std::string & username, std::string & password,
                const std::string & extra_usage = (std::string)"");

/** Function that handles the command line arguments sent to the program
 *  and initializes the transport accordingly
 * @param sess Session to use when communicating with server
 * @param argc Count of command line arguments
 * @param argv Actual command line arguments
 * @param username Login name on server
 * @param password Password on server
 * @param extra_usage Extra usage parameters
 * @return true if arguments set correcetly, otherwise false
 */
bool handleArgs(eppobject::epp::epp_Session & sess, 
		int argc, char * argv[],
		std::string & username, std::string & password,
                const std::vector<std::string> & extra_usage);

/** Function that tries to login to a server using information in the
 *  eppobject::epp::epp_Session object
 * @param mySession Session data to use when communication with server
 * @param username Login name on server
 * @param password Password on server
 */
void testLogIn(eppobject::epp::epp_Session & mySession,
	       const std::string & username,
	       const std::string & password);

/** Function that takes a testdata string and puts each quoted element
 *  into a map
 * @param testdata String with test data
 * @return Map of testdata elements
 */
std::map<unsigned int,std::string> getTestDataMap(const std::string & testdata);

/** Function that takes an extradata string and puts each token element
 *  into a map -- tokens are separated by ':'.
 *  Used as an alternative to getTestDataMap()
 * @param testdata String with extra data
 * @return Map of extradata elements
 */
std::map<std::string,std::string> getExtraDataMap(const std::string & extradata);

#endif
