/************************************************************************
 * EPP RTK C++
 * Copyright (C) 2001, 2002, 2003  The Global Name Registry, Limited
 * 
 * This library is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published
 * by the Free Software Foundation; either version 2.1 of the License, or
 * (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact information:  epprtk@gnr.com
 *
 *                       EPP RTK
 *                       The Global Name Registry, Limited
 *                       125 High Holborn
 *                       London WC1V 6QA
 *                       United Kingdom
 ************************************************************************/

/* $Header: /cvsroot/epp-rtk/epp-rtk/c++/src/transport/epp_TransportSSL.cc,v 1.25 2003/07/18 20:21:19 tubadanm Exp $ */

/** @file epp_TransportSSL.cc
 *  @brief Definition of epp_TransportSSL functions
 *  @author Asbjorn Steira Mikkelsen
 *  @see epp_TransportSSL.h
 */

#include "epp_TransportSSL.h"
#include <openssl/ssl.h>

// Socket:
#include <sys/types.h>
#include <sys/socket.h>
#include <netinet/in.h>
#include <arpa/inet.h>
#include <stdio.h>
#include <unistd.h>
#include <netdb.h>
/////////


using namespace std;
using namespace epptransport;
using namespace npbase;


void epp_TransportSSL::writeToServer(const string & xml_string)
{
   string send_xml = "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"no\"?>";
   send_xml += xml_string;
   
   // Deleting trailing whitespace from request:
   string::size_type lastNotWhite = send_xml.find_last_not_of(" \t\r\n");
   if(lastNotWhite != (send_xml.length()-1) && lastNotWhite != 0) {
      
      //lint -e534
      // We are not interested in the return value here:
      send_xml.erase(lastNotWhite+1, send_xml.length());
      //lint +e534
   }
   
#ifdef RTK_DEBUG
   cout << "<Writing_to_server>" << endl;
   cout << "["<<send_xml<<"]" << endl;
   cout << "</Writing_to_server>" << endl;
#endif

   if(!connected() || !sslserver) {
      throw epp_TrException(__FILE__, __LINE__, "Not connected to server");
   }
   
   // write the 4 byte header...
#ifdef RTK_DEBUG
   cout << "The length of the xml is ["<<send_xml.length()<<"]" << endl;
#endif
   long int message_length = send_xml.length() + 4;
   char header_bytes[4];
   memset(header_bytes, 0, 4);
   header_bytes[0] = ( message_length >> 24 ) & 0xff;
   header_bytes[1] = ( message_length >> 16 ) & 0xff;
   header_bytes[2] = ( message_length >> 8  ) & 0xff;
   header_bytes[3] = ( message_length )       & 0xff ;
   
   if ( not sslserver->putchars(header_bytes, 4) ) {
      throw epp_TrException(__FILE__, __LINE__, "Unable to write epp header to server");
   }
   
   try {
      //lint -e534
      // We are not interested in the return values here:
      sslserver->bufferedPutS(send_xml);
      sslserver->flush();
      //lint +e534
   }
   catch(...) {
      throw epp_TrException(__FILE__, __LINE__, "Unable to write xml message to server");
   }
}


string epp_TransportSSL::readFromServer()
{
   if(!connected() || !sslserver) {
      throw epp_TrException(__FILE__, __LINE__, "Not connected to server");
   }
   
   string s;
   
   unsigned long int header_length = 0;
   
   try {
      
      char header[4];
      memset(header, 0, 4);
      const char *temp_ptr;
      temp_ptr = sslserver->getchars(4);
      if ( temp_ptr[0] ==  -1 ) {
	 throw epp_TrException(__FILE__, __LINE__, "Unable to read header from server");
      }
      memcpy(header, temp_ptr, 4);
      
      header_length = ( ( header[0] & 0xff ) << 24 ) |
                      ( ( header[1] & 0xff ) << 16 ) |
                      ( ( header[2] & 0xff ) << 8  ) |
                      ( ( header[3] & 0xff ) );

      header_length -= 4; // less the size of the header
      
#ifdef RTK_DEBUG
      cout << "Length of XML from the server is ["<< header_length <<"]" << endl;
      cout << "Byte 1 ["<< (unsigned int)header[0] <<"] Byte 4 ["<< (unsigned int)header[3] <<"]" << endl;
#endif
      
      if ( header_length > 0 ) {
         temp_ptr = sslserver->getchars(header_length);
         if ( temp_ptr[0] ==  -1 ) {
	    throw epp_TrException(__FILE__, __LINE__, "Unable to read xml message from server (byte1)");
         }
         s = temp_ptr;
      }
   }
   catch(epp_TrException & e) {
      throw e;
   }
   catch(...) {
      throw epp_TrException(__FILE__, __LINE__, "Unable to read from server");
   }
   
   return s;
}


void epp_TransportSSL::connect(const string & serverName, const unsigned long & serverPort,
			       const string & certFile, const string & cacertFile /* = "" */,
			       const string & cacertDir /* = "" */)
{
   m_serverName = serverName;
   m_serverPort = serverPort;
   m_certFile = certFile;
   m_cacertFile = cacertFile;
   m_cacertDir = cacertDir;
   connect();
}


void epp_TransportSSL::connect(const string & serverName, const unsigned long & serverPort)
{
   m_serverName = serverName;
   m_serverPort = serverPort;
   connect();
}


void epp_TransportSSL::connect()
{
   struct sockaddr_in address;
   
   sockfd = socket(AF_INET, SOCK_STREAM, 0);
   address.sin_family = AF_INET;

   // IP-lookup code from tubadanm:
   struct hostent *hostp = gethostbyname(m_serverName.c_str());
   memcpy( (char *)(&(address.sin_addr)), (char *)(hostp->h_addr),
	  hostp->h_length );
   
   address.sin_port = ntohs(m_serverPort);
   int len = sizeof(address);
   
//   cout << "Connecting to " << m_serverName  << ":" << m_serverPort << endl;   
   int result = ::connect(sockfd,(struct sockaddr *) &address, len);
   
   if(result == -1) {
      throw epp_TrException(__FILE__, __LINE__, "Unable to connect to server");
   }

   try {
      sslserver = new npssl(65635,false);
      sslserver->setCertFile(m_certFile);
      if (!m_cacertFile.empty()) {
	 sslserver->setVerifyLocations(m_cacertFile,m_cacertDir);
      }
      sslserver->newConnection();
   }
   catch (...) {
      throw epp_TrException(__FILE__, __LINE__, "Unable to set up connection to server");
   }
   
   if(!sslserver->handShake(sockfd, sockfd)) {
      throw epp_TrException(__FILE__, __LINE__, "SSL handshake failed. Terminating connection.");
   }   

}


void epp_TransportSSL::disconnect()
{
   delete sslserver;
   sslserver = (npbase::npssl *)NULL;
}
