/************************************************************************
* EPP RTK C++
* Copyright (C) 2001, 2002 The Global Name Registry, Limited 
* 
* This library is free software; you can redistribute it and/or modify it
* under the terms of the GNU Lesser General Public License as published
* by the Free Software Foundation; either version 2.1 of the License, or
* (at your option) any later version.
*
* This library is distributed in the hope that it will be useful, but
* WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
* Lesser General Public License for more details.
*
* You should have received a copy of the GNU Lesser General Public
* License along with this library; if not, write to the Free Software
* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*
* Contact information:  epprtk@gnr.com
*
*                       EPP RTK
*                       The Global Name Registry, Limited
*                       125 High Holborn
*                       London WC1V 6QA
*                       United Kingdom
************************************************************************/

#ifndef __EPP_UNSPECTEST_H
#define __EPP_UNSPECTEST_H

/** @file epp_UnspecTest.h
 *  @brief Declaration of epp_UnspecTest and epp_UnspecTest_ref
 *  @author Asbjorn Steira Mikkelsen
 */

#include <domtools/dom_output.h>
#include <domtools/dom_wrapper.h>
#include "../config.h"
#include "epp_Weather.h"
#include "../data/epp_eppXMLbase.h"
#include "../data/epp_XMLException.h"


namespace eppobject { namespace epp {
   
   /// Weather test class utilizing the extension framework
   /// @see epp_Extension for additional information
   class epp_UnspecTest : public epp_Extension {
      
    public:
      epp_Weather_ref m_weather; /**< Element with server weather information/forecast */
      
      /// Null constructor
      epp_UnspecTest() {};

      /// Destructor
      virtual ~epp_UnspecTest() {};
      
      /// Returns the #epp_Weather response data
      /// @return Weather response object
      epp_Weather_ref getResponseData()
	{
	   return m_weather;
	}
      
      /// Converts the request data object (if any) to xml and returns it as an #epp_string
      /// @return The request xml string
      virtual eppobject::epp::epp_string toXML()
	{
	   domtools::xml_string_output xmltext;
	   xmltext.setWhitespace(false);
	   
	   xmltext.putTag("weatherforecast", "");
	   
	   return xmltext.getString();
	};
      
      /// Converts a (response) xml string into the response data object
      /// @param xml The response xml string
      virtual void fromXML(const eppobject::epp::epp_string & xml)
	{
	   m_weather.ref(new epp_Weather());
	   
	   domtools::dom_ptr doc = createDOMDocument(xml);
	   
	   domtools::dom_ptr todayNode = domtools::dom_ptr(doc->getTag("today"));

	   if(!todayNode->isNull())
	     {
		std::string today = todayNode->getNodeData();
		m_weather->m_today.ref(new epp_string(today));
	     }

	   domtools::dom_ptr tomorrowNode = domtools::dom_ptr(doc->getTag("tomorrow"));
	   if(!tomorrowNode->isNull())
	     {
		std::string tomorrow = tomorrowNode->getNodeData();
		m_weather->m_tomorrow.ref(new epp_string(tomorrow));
	     }
	   
	};
   };
   
   /// Typedef for the ref to the epp_UnspecTest class
   typedef refcnt_ptr<epp_UnspecTest> epp_UnspecTest_ref;
   
}}

#endif
